@@ -1591,7 +1591,7 @@ static void adjust_improvement_wants_by_effects(struct ai_type *ait,
   } players_iterate_end;
 
   effect_list_iterate(get_req_source_effects(&source), peffect) {
-    struct requirement *mypreq = NULL;
+    enum req_range range = REQ_RANGE_MAX;
     bool active = TRUE;
     int n_needed_techs = 0;
     struct tech_vector needed_techs;
@@ -1604,8 +1604,11 @@ static void adjust_improvement_wants_by_effects(struct ai_type *ait,
       /* Check if all the requirements for the currently evaluated effect
        * are met, except for having the building that we are evaluating. */
       if (VUT_IMPROVEMENT == preq->source.kind
-	  && preq->source.value.building == pimprove) {
-	mypreq = preq;
+          && preq->source.value.building == pimprove) {
+        if (preq->range < range) {
+          /* More limited range */
+          range = preq->range;
+        }
         present = preq->present;
         continue;
       }
@@ -1627,8 +1630,7 @@ static void adjust_improvement_wants_by_effects(struct ai_type *ait,
     n_needed_techs = tech_vector_size(&needed_techs);
     if ((active || n_needed_techs) && !impossible_to_get) {
       adv_want v1 = dai_effect_value(pplayer, ai, pcity, capital,
-                                     turns, peffect, cities[mypreq->range],
-                                     nplayers);
+                                     turns, peffect, range, nplayers);
       /* v1 could be negative (the effect could be undesirable),
        * although it is usually positive.
        * For example, in the default ruleset, Communism decreases the
@@ -1681,7 +1683,9 @@ static void adjust_improvement_wants_by_effects(struct ai_type *ait,
 
     /* Is it possible to do the action to the city right now?
      *
-     * (DiplRel requirements are ignored since actor_player is NULL) */
+     * (DiplRel requirements are ignored since actor_player is NULL)
+     *
+     * See TODO below about keeping this in sync with 'will_be_possible' */
     is_possible = is_action_possible_on_city(act_id, NULL, pcity);
 
     /* Will it be possible to do the action to the city if the building is
@@ -1702,12 +1706,15 @@ static void adjust_improvement_wants_by_effects(struct ai_type *ait,
             active = FALSE;
             break;
           }
-        }
-
-        if (!is_req_active(pplayer, NULL, pcity, pimprove,
-                           city_tile(pcity), NULL, NULL, NULL, NULL,
-                           NULL,
-                           preq, RPT_POSSIBLE)) {
+        } else if (!is_req_active(pplayer, NULL, pcity, NULL,
+                                  city_tile(pcity), NULL, NULL, NULL, NULL,
+                                  NULL,
+                                  preq, RPT_POSSIBLE)) {
+          /* TODO: Make this more robust! Now we must be really careful
+           *       that 'is_possible' is checked by exatly similar context
+           *       to this 'will_be_possible' or either one may trip on
+           *       a requirement that the other one does not, causing
+           *       them to differ when they should not. */
           active = FALSE;
           break;
         }
