@@ -46,7 +46,7 @@
 #include "mapview_common.h"
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* gui-gtk-2.0 */
 #include "chatline.h"
 #include "citydlg.h"
 #include "gui_main.h"
@@ -61,8 +61,8 @@
 #define NEG_VAL(x)  ((x)<0 ? (x) : (-x))
 
 /* Some versions of gcc have problems with negative values here (PR#39722). */
-#define CMA_NONE	(10000)
-#define CMA_CUSTOM	(10001)
+#define CMA_NONE        (10000)
+#define CMA_CUSTOM      (10001)
 
 struct sell_data {
   int count;                    /* Number of cities. */
@@ -400,8 +400,7 @@ static void append_impr_or_unit_to_menu_item(GtkMenuItem *parent_item,
     get_city_dialog_production_row(row, sizeof(buf[0]), &target, NULL);
 
     menu_item = gtk_menu_item_new();
-    hbox = gtk_grid_new();
-    gtk_grid_set_column_spacing(GTK_GRID(hbox), 18);
+    hbox = gtk_hbox_new(FALSE, 18);
     gtk_container_add(GTK_CONTAINER(menu_item), hbox);
 
     for (i = 0; i < 3; i++) {
@@ -419,20 +418,13 @@ static void append_impr_or_unit_to_menu_item(GtkMenuItem *parent_item,
       label = gtk_label_new(NULL);
       gtk_label_set_markup(GTK_LABEL(label), txt);
 
-      switch (i) {
-        case 0:
-          gtk_widget_set_halign(label, GTK_ALIGN_START);
-          gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-        break;
-        case 2:
-          gtk_widget_set_halign(label, GTK_ALIGN_END);
-          gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-          break;
-        default:
-          break;
+      if (i < 2) {
+	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
+      } else {
+	gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
       }
 
-      gtk_container_add(GTK_CONTAINER(hbox), label);
+      gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, FALSE, 0);
       gtk_size_group_add_widget(group[i], label);
     }
 
@@ -567,7 +559,7 @@ static void sell_impr_iterate(GtkTreeModel *model, GtkTreePath *path,
 static void select_impr_or_unit_callback(GtkWidget *wdg, gpointer data)
 {
   struct universal target = cid_decode(GPOINTER_TO_INT(data));
-  GObject *parent = G_OBJECT(gtk_widget_get_parent(wdg));
+  GObject *parent = G_OBJECT(wdg->parent);
   TestCityFunc test_func = g_object_get_data(parent, "freeciv_test_func");
   enum city_operation_type city_operation = 
     GPOINTER_TO_INT(g_object_get_data(parent, "freeciv_city_operation"));
@@ -693,7 +685,7 @@ static void cma_iterate(GtkTreeModel *model, GtkTreePath *path,
 static void select_cma_callback(GtkWidget * w, gpointer data)
 {
   int idx = GPOINTER_TO_INT(data);
-  GObject *parent = G_OBJECT(gtk_widget_get_parent(w));
+  GObject *parent = G_OBJECT(w->parent);
   bool change_cma =
       GPOINTER_TO_INT(g_object_get_data(parent, "freeciv_change_cma"));
   struct cm_parameter parameter;
@@ -742,10 +734,10 @@ static void select_cma_callback(GtkWidget * w, gpointer data)
 }
 
 /****************************************************************
- Create the cma entries in the change menu and the select menu. The
- indices CMA_NONE and CMA_CUSTOM are special.
- CMA_NONE signifies a preset of "none" and CMA_CUSTOM a
- "custom" preset.
+  Create the cma entries in the change menu and the select menu.
+  The indices CMA_NONE and CMA_CUSTOM are special.
+  CMA_NONE signifies a preset of "none" and CMA_CUSTOM a
+  "custom" preset.
 *****************************************************************/
 static void append_cma_to_menu_item(GtkMenuItem *parent_item, bool change_cma)
 {
@@ -755,7 +747,7 @@ static void append_cma_to_menu_item(GtkMenuItem *parent_item, bool change_cma)
   GtkWidget *w;
 
   w = gtk_menu_item_get_submenu(parent_item);
-  if (w != NULL && gtk_widget_get_visible(w)) {
+  if (w != NULL && GTK_WIDGET_VISIBLE(w)) {
     return;
   }
 
@@ -767,7 +759,7 @@ static void append_cma_to_menu_item(GtkMenuItem *parent_item, bool change_cma)
   gtk_menu_item_set_submenu(parent_item, menu);
 
   if (change_cma) {
-    w = gtk_menu_item_new_with_label(_("none"));
+    w = gtk_menu_item_new_with_label(Q_("?cma:none"));
     gtk_menu_shell_append(GTK_MENU_SHELL(menu), w);
     g_signal_connect(w, "activate", G_CALLBACK(select_cma_callback),
                      GINT_TO_POINTER(CMA_NONE));
@@ -781,69 +773,71 @@ static void append_cma_to_menu_item(GtkMenuItem *parent_item, bool change_cma)
       fc_assert(GPOINTER_TO_INT(GINT_TO_POINTER(i)) == i);
     }
   } else {
-    /* search for a "none" */
+    /* Search for a "none" */
     int found;
 
     found = 0;
     city_list_iterate(client.conn.playing->cities, pcity) {
       if (!cma_is_city_under_agent(pcity, NULL)) {
-	found = 1;
-	break;
+        found = 1;
+        break;
       }
     } city_list_iterate_end;
 
     if (found) {
-      w = gtk_menu_item_new_with_label(_("none"));
+      w = gtk_menu_item_new_with_label(Q_("?cma:none"));
       gtk_menu_shell_append(GTK_MENU_SHELL(menu), w);
       g_signal_connect(w, "activate", G_CALLBACK(select_cma_callback),
-		       GINT_TO_POINTER(CMA_NONE));
+                       GINT_TO_POINTER(CMA_NONE));
     }
 
-    /* 
+    /*
      * Search for a city that's under custom (not preset) agent. Might
      * take a lonnggg time.
      */
     found = 0;
     city_list_iterate(client.conn.playing->cities, pcity) {
       if (cma_is_city_under_agent(pcity, &parameter) &&
-	  cmafec_preset_get_index_of_parameter(&parameter) == -1) {
-	found = 1;
-	break;
+          cmafec_preset_get_index_of_parameter(&parameter) == -1) {
+        found = 1;
+        break;
       }
     } city_list_iterate_end;
 
     if (found) {
-      /* we found city that's under agent but not a preset */
-      w = gtk_menu_item_new_with_label(_("custom"));
+      /* We found city that's under agent but not a preset */
+      w = gtk_menu_item_new_with_label(Q_("?cma:custom"));
 
       gtk_menu_shell_append(GTK_MENU_SHELL(menu), w);
       g_signal_connect(w, "activate",
-	G_CALLBACK(select_cma_callback), GINT_TO_POINTER(CMA_CUSTOM));
+                       G_CALLBACK(select_cma_callback),
+                       GINT_TO_POINTER(CMA_CUSTOM));
     }
 
-    /* only fill in presets that are being used. */
+    /* Only fill in presets that are being used. */
     for (i = 0; i < cmafec_preset_num(); i++) {
       found = 0;
       city_list_iterate(client.conn.playing->cities, pcity) {
-	if (cma_is_city_under_agent(pcity, &parameter) &&
-	    cm_are_parameter_equal(&parameter,
-				   cmafec_preset_get_parameter(i))) {
-	  found = 1;
-	  break;
-	}
+        if (cma_is_city_under_agent(pcity, &parameter) &&
+            cm_are_parameter_equal(&parameter,
+                                   cmafec_preset_get_parameter(i))) {
+          found = 1;
+          break;
+        }
       } city_list_iterate_end;
-      if (found) {
-	w = gtk_menu_item_new_with_label(cmafec_preset_get_descr(i));
 
-      gtk_menu_shell_append(GTK_MENU_SHELL(menu), w);
-	g_signal_connect(w, "activate",
-	  G_CALLBACK(select_cma_callback), GINT_TO_POINTER(i));
+      if (found) {
+        w = gtk_menu_item_new_with_label(cmafec_preset_get_descr(i));
+
+        gtk_menu_shell_append(GTK_MENU_SHELL(menu), w);
+        g_signal_connect(w, "activate",
+                         G_CALLBACK(select_cma_callback), GINT_TO_POINTER(i));
       }
     }
   }
 
   g_object_set_data(G_OBJECT(menu), "freeciv_change_cma",
-		    GINT_TO_POINTER(change_cma));
+                    GINT_TO_POINTER(change_cma));
   gtk_widget_show_all(menu);
 }
 
@@ -946,7 +940,7 @@ static void production_menu_shown(GtkWidget *widget, gpointer data)
   fc_assert_ret(callback != NULL);
 
   menu = gtk_menu_item_get_submenu(parent_item);
-  if (menu != NULL && gtk_widget_get_visible(menu)) {
+  if (menu != NULL && GTK_WIDGET_VISIBLE(menu)) {
     gtk_menu_shell_deactivate(GTK_MENU_SHELL(menu));
   }
 
@@ -1039,14 +1033,12 @@ static GtkWidget *create_city_report_menubar(void)
 {
   GtkWidget *vbox, *sep, *menubar, *menu, *item;
 
-  vbox = gtk_grid_new();
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(vbox),
-                                 GTK_ORIENTATION_VERTICAL);
-  sep = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
-  gtk_container_add(GTK_CONTAINER(vbox), sep);
+  vbox = gtk_vbox_new(FALSE, 0);
+  sep = gtk_hseparator_new();
+  gtk_box_pack_start(GTK_BOX(vbox), sep, FALSE, FALSE, 0);
 
   menubar = gtk_aux_menu_bar_new();
-  gtk_container_add(GTK_CONTAINER(vbox), menubar);
+  gtk_box_pack_start(GTK_BOX(vbox), menubar, TRUE, TRUE, 0);
   
   item = gtk_menu_item_new_with_mnemonic(_("_Production"));
   city_production_command = item;
@@ -1155,24 +1147,23 @@ static void create_city_report_dialog(bool make_modal)
   gui_dialog_add_widget(city_dialog_shell, menubar);
 
   /* buttons */
-  city_total_buy_cost_label = gtk_label_new(NULL);
-  gtk_widget_set_hexpand(city_total_buy_cost_label, TRUE);
-  gtk_label_set_ellipsize(GTK_LABEL(city_total_buy_cost_label),
-                          PANGO_ELLIPSIZE_START);
-  gtk_container_add(GTK_CONTAINER(city_dialog_shell->action_area),
-                    city_total_buy_cost_label);
+  w = gui_dialog_add_stockbutton(city_dialog_shell, GTK_STOCK_ZOOM_FIT,
+      _("Cen_ter"), CITY_CENTER);
+  city_center_command = w;
 
-  w = gui_dialog_add_button(city_dialog_shell, NULL,
-                            _("_Buy"), CITY_BUY);
-  city_buy_command = w;
-
-  w = gui_dialog_add_button(city_dialog_shell, NULL,
-                            _("_Inspect"), CITY_POPUP);
+  w = gui_dialog_add_stockbutton(city_dialog_shell, GTK_STOCK_ZOOM_IN,
+      _("_Inspect"), CITY_POPUP);
   city_popup_command = w;
 
-  w = gui_dialog_add_button(city_dialog_shell, NULL,
-                            _("Cen_ter"), CITY_CENTER);
-  city_center_command = w;
+  w = gui_dialog_add_stockbutton(city_dialog_shell, GTK_STOCK_EXECUTE,
+      _("_Buy"), CITY_BUY);
+  city_buy_command = w;
+
+  city_total_buy_cost_label = gtk_label_new(NULL);
+  gtk_label_set_ellipsize(GTK_LABEL(city_total_buy_cost_label),
+                          PANGO_ELLIPSIZE_START);
+  gtk_box_pack_end(GTK_BOX(city_dialog_shell->action_area),
+                   city_total_buy_cost_label, TRUE, TRUE, 0);
 
   gui_dialog_set_default_response(city_dialog_shell,
                                   GTK_RESPONSE_CLOSE);
@@ -1188,8 +1179,6 @@ static void create_city_report_dialog(bool make_modal)
   city_model = city_report_dialog_store_new();
 
   city_view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(city_model));
-  gtk_widget_set_hexpand(city_view, TRUE);
-  gtk_widget_set_vexpand(city_view, TRUE);
   g_object_unref(city_model);
   gtk_widget_set_name(city_view, "small_font");
   g_signal_connect(city_view, "row_activated",
@@ -1228,7 +1217,8 @@ static void create_city_report_dialog(bool make_modal)
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
   gtk_container_add(GTK_CONTAINER(sw), city_view);
 
-  gtk_container_add(GTK_CONTAINER(city_dialog_shell->vbox), sw);
+  gtk_box_pack_start(GTK_BOX(city_dialog_shell->vbox),
+                     sw, TRUE, TRUE, 0);
 
   city_model_fill(city_model, NULL, NULL);
   gui_dialog_show_all(city_dialog_shell);
@@ -1419,12 +1409,10 @@ static void city_command_callback(struct gui_dialog *dlg, int response,
   User has selected city row from city report.
 *****************************************************************/
 static void city_activated_callback(GtkTreeView *view, GtkTreePath *path,
-                                    GtkTreeViewColumn *col, gpointer data)
+				    GtkTreeViewColumn *col, gpointer data)
 {
   GtkTreeModel *model;
   GtkTreeIter iter;
-  GdkWindow *win;
-  GdkSeat *seat;
   GdkModifierType mask;
 
   model = gtk_tree_view_get_model(view);
@@ -1433,11 +1421,7 @@ static void city_activated_callback(GtkTreeView *view, GtkTreePath *path,
     return;
   }
 
-  win = gdk_get_default_root_window();
-  seat = gdk_display_get_default_seat(gdk_window_get_display(win));
-
-  gdk_window_get_device_position(win, gdk_seat_get_pointer(seat),
-                                 NULL, NULL, &mask);
+  gdk_window_get_pointer(NULL, NULL, NULL, &mask);
 
   if (!(mask & GDK_CONTROL_MASK)) {
     popup_iterate(model, path, &iter, NULL);
@@ -1474,7 +1458,7 @@ void real_city_report_dialog_update(void *unused)
   city_model_fill(city_model, city_selection, selected);
   g_hash_table_destroy(selected);
 
-  if (gtk_widget_get_sensitive(city_governor_command)) {
+  if (GTK_WIDGET_SENSITIVE(city_governor_command)) {
     append_cma_to_menu_item(GTK_MENU_ITEM(city_governor_command), TRUE);
   }
 
@@ -1660,7 +1644,7 @@ static void popup_last_menu(GtkMenuShell *menu, gpointer data)
 }
 
 /****************************************************************
-  Pops up the first menu.
+pops up the first menu.
 *****************************************************************/
 static void popup_first_menu(GtkMenuShell *menu, gpointer data)
 {
@@ -1989,6 +1973,7 @@ static void update_total_buy_cost(void)
 
   if (total > 0) {
     gchar *buf = g_strdup_printf(_("Total Buy Cost: %d"), total);
+
     gtk_label_set_text(GTK_LABEL(label), buf);
     g_free(buf);
   } else {
