@@ -1,4 +1,4 @@
-/***********************************************************************
+/**********************************************************************
  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@
 #include "climisc.h"
 #include "options.h"
 
-/* client/gui-gtk-3.22 */
+/* client/gui-gtk-3.0 */
 #include "diplodlg.h"
 #include "gui_main.h"
 #include "gui_stuff.h"
@@ -499,11 +499,11 @@ static struct Diplomacy_notebook *diplomacy_main_create(void)
     gtk_container_add(GTK_CONTAINER(dipl_sw), dipl_main->notebook);
 
     /* Buttons */
-    gui_dialog_add_button(dipl_main->dialog, NULL,
-                          _("Cancel _all meetings"),
-                          RESPONSE_CANCEL_MEETING_ALL);
+    gui_dialog_add_stockbutton(dipl_main->dialog, GTK_STOCK_CANCEL,
+                               _("Cancel _all meetings"),
+                               RESPONSE_CANCEL_MEETING_ALL);
 
-    /* Responces for _all_ meetings. */
+    /* Responses for _all_ meetings. */
     gui_dialog_response_set_callback(dipl_main->dialog,
                                      diplomacy_main_response);
     gui_dialog_set_default_response(dipl_main->dialog,
@@ -655,12 +655,12 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   gui_dialog_new(&(pdialog->dialog), GTK_NOTEBOOK(notebook), pdialog, FALSE);
 
   /* Buttons */
-  gui_dialog_add_button(pdialog->dialog, NULL,
-                        _("Accept treaty"), GTK_RESPONSE_ACCEPT);
-  gui_dialog_add_button(pdialog->dialog, NULL,
-                        _("Cancel meeting"), RESPONSE_CANCEL_MEETING);
+  gui_dialog_add_stockbutton(pdialog->dialog, GTK_STOCK_DND,
+                             _("Accept treaty"), GTK_RESPONSE_ACCEPT);
+  gui_dialog_add_stockbutton(pdialog->dialog, GTK_STOCK_CANCEL,
+                             _("Cancel meeting"), RESPONSE_CANCEL_MEETING);
 
-  /* Responces for one meeting. */
+  /* Responses for one meeting. */
   gui_dialog_response_set_callback(pdialog->dialog, diplomacy_response);
   gui_dialog_set_default_response(pdialog->dialog, RESPONSE_CANCEL_MEETING);
 
@@ -737,7 +737,10 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   menu = gtk_menu_new();
   pdialog->menu0 = menu;
 
-  menuitem = gtk_menu_item_new_with_label(_("Add Clause..."));
+  menuitem = gtk_image_menu_item_new_with_label(_("Add Clause..."));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem),
+                                gtk_image_new_from_stock(GTK_STOCK_ADD,
+                                                         GTK_ICON_SIZE_MENU));
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menubar), menuitem);
   g_object_set_data(G_OBJECT(menu), "plr", plr0);
@@ -819,7 +822,10 @@ static struct Diplomacy_dialog *create_diplomacy_dialog(struct player *plr0,
   menu = gtk_menu_new();
   pdialog->menu1 = menu;
 
-  menuitem = gtk_menu_item_new_with_label(_("Add Clause..."));
+  menuitem = gtk_image_menu_item_new_with_label(_("Add Clause..."));
+  gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem),
+                                gtk_image_new_from_stock(GTK_STOCK_ADD,
+                                                         GTK_ICON_SIZE_MENU));
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), menu);
   gtk_menu_shell_append(GTK_MENU_SHELL(menubar), menuitem);
   g_object_set_data(G_OBJECT(menu), "plr", plr1);
