@@ -1048,6 +1048,25 @@ static void setup_canvas_color_for_state(GtkStateFlags state)
 }
 #endif
 
+/**************************************************************************
+  Update tooltip of the Turn Done button
+**************************************************************************/
+void update_turn_done_tooltip(void)
+{
+  struct option *opt = optset_option_by_name(server_optset, "fixedlength");
+
+  if (opt != NULL && option_bool_get(opt)) {
+    gtk_widget_set_tooltip_text(turn_done_button,
+                                _("Fixed length turns"));
+  } else {
+    char buf[256];
+
+    fc_snprintf(buf, sizeof(buf), "%s:\n%s",
+                _("Turn Done"), _("Shift+Return"));
+    gtk_widget_set_tooltip_text(turn_done_button, buf);
+  }
+}
+
 /**************************************************************************
   Do the heavy lifting for the widget setup.
 **************************************************************************/
@@ -1057,7 +1076,6 @@ static void setup_widgets(void)
   GtkWidget *frame, *table, *table2, *paned, *sw, *text;
   GtkWidget *button, *view, *vgrid, *right_vbox = NULL;
   int i;
-  char buf[256];
   GtkWidget *notebook, *statusbar;
   GtkWidget *dtach_lowbox = NULL;
   struct sprite *spr;
@@ -1066,9 +1084,9 @@ static void setup_widgets(void)
 
   notebook = gtk_notebook_new();
 
-  /* stop mouse wheel notebook page switching. */
+  /* Stop mouse wheel notebook page switching. */
   g_signal_connect(notebook, "scroll_event",
-		   G_CALLBACK(gtk_true), NULL);
+                   G_CALLBACK(gtk_true), NULL);
 
   toplevel_tabs = notebook;
   gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook), FALSE);
@@ -1153,7 +1171,7 @@ static void setup_widgets(void)
   gtk_grid_attach_next_to(GTK_GRID(hgrid), vgrid, right_vbox,
                           GTK_POS_LEFT, 1, 1);
 
-  /* overview canvas */
+  /* Overview canvas */
   ahbox = detached_widget_new();
   gtk_widget_set_hexpand(ahbox, FALSE);
   gtk_widget_set_vexpand(ahbox, FALSE);
@@ -1236,7 +1254,7 @@ static void setup_widgets(void)
   gtk_grid_set_column_homogeneous(GTK_GRID(table), TRUE);
   gtk_container_add(GTK_CONTAINER(avbox), table);
 
-  /* citizens for taxrates */
+  /* Citizens for taxrates */
   ebox = gtk_event_box_new();
   gtk_event_box_set_visible_window(GTK_EVENT_BOX(ebox), FALSE);
   gtk_grid_attach(GTK_GRID(table), ebox, 0, 0, 10, 1);
@@ -1260,7 +1278,7 @@ static void setup_widgets(void)
     gtk_container_add(GTK_CONTAINER(ebox), econ_label[i]);
   }
 
-  /* science, environmental, govt, timeout */
+  /* Science, environmental, govt, timeout */
   spr = client_research_sprite();
   if (spr != NULL) {
     bulb_label = gtk_image_new_from_surface(spr->surface);
@@ -1332,17 +1350,14 @@ static void setup_widgets(void)
   gtk_container_add(GTK_CONTAINER(frame), timeout_label);
 
 
-  /* turn done */
+  /* Turn done */
   turn_done_button = gtk_button_new_with_label(_("Turn Done"));
 
   gtk_grid_attach(GTK_GRID(table), turn_done_button, 0, 2, 10, 1);
 
   g_signal_connect(turn_done_button, "clicked",
                    G_CALLBACK(end_turn_callback), NULL);
-
-  fc_snprintf(buf, sizeof(buf), "%s:\n%s",
-              _("Turn Done"), _("Shift+Return"));
-  gtk_widget_set_tooltip_text(turn_done_button, buf);
+  update_turn_done_tooltip();
 
   /* Selected unit status */
 
@@ -1879,11 +1894,6 @@ int ui_main(int argc, char **argv)
   gtk_main();
   gui_up = FALSE;
 
-  /* We have extra ref for unit_info_box that has protected
-   * it from getting destroyed when editinfobox_refresh()
-   * moves widgets around. Free that extra ref here. */
-  g_object_unref(unit_info_box);
-
   destroy_server_scans();
   free_mapcanvas_and_overview();
   spaceship_dialog_done();
@@ -1894,6 +1904,12 @@ int ui_main(int argc, char **argv)
   diplomacy_dialog_done();
   cma_fe_done();
   free_unit_table();
+
+  /* We have extra ref for unit_info_box that has protected
+   * it from getting destroyed when editinfobox_refresh()
+   * moves widgets around. Free that extra ref here. */
+  g_object_unref(unit_info_box);
+
   editgui_free();
   gtk_widget_destroy(toplevel_tabs);
   gtk_widget_destroy(toplevel);
@@ -2099,8 +2115,8 @@ static gboolean show_info_popup(GtkWidget *w, GdkEventButton *ev, gpointer data)
 **************************************************************************/
 static void end_turn_callback(GtkWidget *w, gpointer data)
 {
-    gtk_widget_set_sensitive(turn_done_button, FALSE);
-    user_ended_turn();
+  gtk_widget_set_sensitive(turn_done_button, FALSE);
+  user_ended_turn();
 }
 
 /**************************************************************************
@@ -2279,6 +2295,18 @@ static void allied_chat_only_callback(struct option *poption)
                                option_bool_get(poption));
 }
 
+/****************************************************************************
+  Option callback for the 'fullscreen' gtk-gui option.
+****************************************************************************/
+void fullscreen_opt_refresh(struct option *poption)
+{
+  if (GUI_GTK_OPTION(fullscreen)) {
+    gtk_window_fullscreen(GTK_WINDOW(toplevel));
+  } else {
+    gtk_window_unfullscreen(GTK_WINDOW(toplevel));
+  }
+}
+
 /****************************************************************************
   Change the city names font.
 ****************************************************************************/
@@ -2330,6 +2358,8 @@ void options_extra_init(void)
 
   option_var_set_callback(allied_chat_only,
                           allied_chat_only_callback);
+  option_var_set_callback(fullscreen,
+                          fullscreen_opt_refresh);
 
   option_var_set_callback(font_city_names,
                           apply_city_names_font);
