@@ -32,7 +32,7 @@
 /* client */
 #include "options.h"
 
-/* client/gui-gtk-3.0 */
+/* client/gui-gtk-3.22 */
 #include "colors.h"
 #include "gui_main.h"
 
@@ -43,6 +43,8 @@ static GList *dialog_list;
 
 static GtkSizeGroup *gui_action;
 
+static GtkCssProvider *dlg_tab_provider = NULL;
+
 
 /**************************************************************************
   Draw widget now
@@ -69,16 +71,20 @@ void set_relative_window_position(GtkWindow *ref, GtkWindow *w, int px, int py)
 }
 
 /**************************************************************************
-  Create new stock button
+  Create new icon button with label
 **************************************************************************/
-GtkWidget *gtk_stockbutton_new(const gchar *stock, const gchar *label_text)
+GtkWidget *icon_label_button_new(const gchar *icon_name,
+                                 const gchar *label_text)
 {
   GtkWidget *button;
   GtkWidget *image;
-  
+
   button = gtk_button_new_with_mnemonic(label_text);
-  image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image(GTK_BUTTON(button), image);
+
+  if (icon_name != NULL) {
+    image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_BUTTON);
+    gtk_button_set_image(GTK_BUTTON(button), image);
+  }
 
   return button;
 }
@@ -425,7 +431,10 @@ static void gui_dialog_switch_page_handler(GtkNotebook *notebook,
   n = gtk_notebook_page_num(GTK_NOTEBOOK(dlg->v.tab.notebook), dlg->vbox);
 
   if (n == num) {
-    gtk_widget_override_color(dlg->v.tab.label, GTK_STATE_FLAG_NORMAL, NULL);
+    GtkStyleContext *context = gtk_widget_get_style_context(dlg->v.tab.label);
+
+    gtk_style_context_remove_class(context, "alert");
+    gtk_style_context_remove_class(context, "notice");
   }
 }
 
@@ -579,8 +588,8 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       label = gtk_label_new(NULL);
       gtk_widget_set_halign(label, GTK_ALIGN_START);
       gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-      gtk_widget_set_margin_left(label, 4);
-      gtk_widget_set_margin_right(label, 4);
+      gtk_widget_set_margin_start(label, 4);
+      gtk_widget_set_margin_end(label, 4);
       gtk_widget_set_margin_top(label, 0);
       gtk_widget_set_margin_bottom(label, 0);
       gtk_container_add(GTK_CONTAINER(hbox), label);
@@ -594,9 +603,9 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
       gtk_widget_set_tooltip_text(button, buf);
       g_free(buf);
 
-      image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-      gtk_widget_set_margin_left(image, 0);
-      gtk_widget_set_margin_right(image, 0);
+      image = gtk_image_new_from_icon_name("window-close", GTK_ICON_SIZE_MENU);
+      gtk_widget_set_margin_start(image, 0);
+      gtk_widget_set_margin_end(image, 0);
       gtk_widget_set_margin_top(image, 0);
       gtk_widget_set_margin_bottom(image, 0);
       gtk_button_set_image(GTK_BUTTON(button), image);
@@ -615,6 +624,9 @@ void gui_dialog_new(struct gui_dialog **pdlg, GtkNotebook *notebook,
                          G_CALLBACK(gui_dialog_switch_page_handler), dlg);
       dlg->v.tab.child = vbox;
 
+      gtk_style_context_add_provider(gtk_widget_get_style_context(label),
+                                     GTK_STYLE_PROVIDER(dlg_tab_provider),
+                                     GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
       dlg->v.tab.label = label;
       dlg->v.tab.notebook = GTK_WIDGET(notebook);
 
@@ -659,7 +671,7 @@ static void action_widget_activated(GtkWidget *button, GtkWidget *vbox)
   Places a button into a dialog, taking care of setting up signals, etc.
 **************************************************************************/
 static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
-				   int response)
+                                   int response)
 {
   gint signal_id;
 
@@ -681,31 +693,16 @@ static void gui_dialog_pack_button(struct gui_dialog *dlg, GtkWidget *button,
   gtk_size_group_add_widget(dlg->gui_button, button);
 }
 
-/**************************************************************************
-  Adds a button to a dialog, allowing the choice of a special stock item.
-**************************************************************************/
-GtkWidget *gui_dialog_add_stockbutton(struct gui_dialog *dlg,
-				      const char *stock,
-				      const char *text, int response)
-{
-  GtkWidget *button;
-
-  button = gtk_stockbutton_new(stock, text);
-  gtk_widget_set_can_default(button, TRUE);
-  gui_dialog_pack_button(dlg, button, response);
-
-  return button;
-}
-
 /**************************************************************************
   Adds a button to a dialog.
 **************************************************************************/
 GtkWidget *gui_dialog_add_button(struct gui_dialog *dlg,
-				 const char *text, int response)
+                                 const char *icon_name,
+                                 const char *text, int response)
 {
   GtkWidget *button;
 
-  button = gtk_button_new_from_stock(text);
+  button = icon_label_button_new(icon_name, text);
   gtk_widget_set_can_default(button, TRUE);
   gui_dialog_pack_button(dlg, button, response);
 
@@ -846,9 +843,9 @@ void gui_dialog_present(struct gui_dialog *dlg)
 
       if (current != n) {
 	GtkWidget *label = dlg->v.tab.label;
-	GdkRGBA color = {.red = 1.0, .green = 0, .blue = 0, .alpha = 1.0};
 
-	gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
+        gtk_style_context_add_class(gtk_widget_get_style_context(label),
+                                    "notice");
       }
     }
     break;
@@ -898,9 +895,11 @@ void gui_dialog_alert(struct gui_dialog *dlg)
 
       if (current != n) {
         GtkWidget *label = dlg->v.tab.label;
-        GdkRGBA color = {.red = 0, .green = 0, .blue =1.0, .alpha = 1.0};
+        GtkStyleContext *context = gtk_widget_get_style_context(label);
 
-        gtk_widget_override_color(label, GTK_STATE_FLAG_NORMAL, &color);
+        /* Have only alert - remove notice if it exist. */
+        gtk_style_context_remove_class(context, "notice");
+        gtk_style_context_add_class(context, "alert");
       }
     }
     break;
@@ -1038,8 +1037,13 @@ void gui_update_font(const char *font_name, const char *font_value)
   size = pango_font_description_get_size(desc);
 
   if (size != 0) {
-    str = g_strdup_printf("#Freeciv #%s { font-family: %s; font-size: %dpx;%s%s}",
-                          font_name, fam, size / PANGO_SCALE, style, weight);
+    if (pango_font_description_get_size_is_absolute(desc)) {
+      str = g_strdup_printf("#Freeciv #%s { font-family: %s; font-size: %dpx;%s%s}",
+                            font_name, fam, size / PANGO_SCALE, style, weight);
+    } else {
+      str = g_strdup_printf("#Freeciv #%s { font-family: %s; font-size: %dpt;%s%s}",
+                            font_name, fam, size / PANGO_SCALE, style, weight);
+    }
   } else {
     str = g_strdup_printf("#Freeciv #%s { font-family: %s;%s%s}",
                           font_name, fam, style, weight);
@@ -1134,5 +1138,23 @@ GtkTreeViewColumn *add_treeview_column(GtkWidget *view, const char *title,
   col = gtk_tree_view_column_new_with_attributes(title, rend, attr,
                                                  model_index, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(view), col);
+
   return col;
 }
+
+/**************************************************************************
+  Prepare dialog tab style provider.
+**************************************************************************/
+void dlg_tab_provider_prepare(void)
+{
+  dlg_tab_provider = gtk_css_provider_new();
+
+  gtk_css_provider_load_from_data(dlg_tab_provider,
+                                  ".alert {\n"
+                                  "color: rgba(255, 0, 0, 255);\n"
+                                  "}\n"
+                                  ".notice {\n"
+                                  "color: rgba(0, 0, 255, 255);\n"
+                                  "}\n",
+                                  -1, NULL);
+}
