@@ -36,7 +36,7 @@
 #include "client_main.h"
 #include "options.h"
 
-/* client/gui-gtk-2.0 */
+/* client/gui-gtk-3.22 */
 #include "gui_main.h"
 #include "gui_stuff.h"
 #include "mapview.h"
@@ -91,27 +91,46 @@ struct intel_dialog {
     TYPED_LIST_ITERATE(struct intel_dialog, dialoglist, pdialog)
 #define dialog_list_iterate_end  LIST_ITERATE_END
 
+struct intel_wonder_dialog {
+  struct player *pplayer;
+  GtkWidget *shell;
+
+  GtkListStore *wonders;
+};
+
+#define SPECLIST_TAG wonder_dialog
+#define SPECLIST_TYPE struct intel_wonder_dialog
+#include "speclist.h"
+
+#define wonder_dialog_list_iterate(dialoglist, pdialog) \
+    TYPED_LIST_ITERATE(struct intel_wonder_dialog, dialoglist, pdialog)
+#define wonder_dialog_list_iterate_end  LIST_ITERATE_END
+
 static struct dialog_list *dialog_list;
 static struct intel_dialog *create_intel_dialog(struct player *p);
+static struct wonder_dialog_list *wonder_dialogs;
+static struct intel_wonder_dialog *create_intel_wonder_dialog(struct player *p);
 
 /****************************************************************
-  Initialize intelligenze dialogs
+  Initialize intelligence dialogs
 *****************************************************************/
 void intel_dialog_init(void)
 {
   dialog_list = dialog_list_new();
+  wonder_dialogs = wonder_dialog_list_new();
 }
 
 /****************************************************************
-  Free resources allocated for intelligenze dialogs
+  Free resources allocated for intelligence dialogs
 *****************************************************************/
 void intel_dialog_done(void)
 {
   dialog_list_destroy(dialog_list);
+  wonder_dialog_list_destroy(wonder_dialogs);
 }
 
 /****************************************************************
-  Get intelligenze dialog between client user and other player
+  Get intelligence dialog between client user and other player
   passed as parameter.
 *****************************************************************/
 static struct intel_dialog *get_intel_dialog(struct player *pplayer)
@@ -125,8 +144,23 @@ static struct intel_dialog *get_intel_dialog(struct player *pplayer)
   return NULL;
 }
 
+/**************************************************************************
+  Get wonder list dialog between client user and other player
+  passed as parameter.
+**************************************************************************/
+static struct intel_wonder_dialog *get_intel_wonder_dialog(struct player *pplayer)
+{
+  wonder_dialog_list_iterate(wonder_dialogs, pdialog) {
+    if (pdialog->pplayer == pplayer) {
+      return pdialog;
+    }
+  } wonder_dialog_list_iterate_end;
+
+  return NULL;
+}
+
 /****************************************************************
-  Open intelligenze dialog
+  Open intelligence dialog
 *****************************************************************/
 void popup_intel_dialog(struct player *p)
 {
@@ -141,8 +175,24 @@ void popup_intel_dialog(struct player *p)
   gtk_window_present(GTK_WINDOW(pdialog->shell));
 }
 
+/**************************************************************************
+  Open wonder list dialog
+**************************************************************************/
+void popup_intel_wonder_dialog(struct player *p)
+{
+  struct intel_wonder_dialog *pdialog;
+
+  if (!(pdialog = get_intel_wonder_dialog(p))) {
+    pdialog = create_intel_wonder_dialog(p);
+  }
+
+  update_intel_wonder_dialog(p);
+
+  gtk_window_present(GTK_WINDOW(pdialog->shell));
+}
+
 /****************************************************************
-  Intelligenze dialog destruction requested
+  Intelligence dialog destruction requested
 *****************************************************************/
 static void intel_destroy_callback(GtkWidget *w, gpointer data)
 {
@@ -153,6 +203,18 @@ static void intel_destroy_callback(GtkWidget *w, gpointer data)
   free(pdialog);
 }
 
+/**************************************************************************
+  Wonders list dialog destruction requested
+**************************************************************************/
+static void intel_wonder_destroy_callback(GtkWidget *w, gpointer data)
+{
+  struct intel_wonder_dialog *pdialog = (struct intel_wonder_dialog *)data;
+
+  wonder_dialog_list_remove(wonder_dialogs, pdialog);
+
+  free(pdialog);
+}
+
 /**************************************************************************
   Close an intelligence dialog for the given player.
 **************************************************************************/
@@ -162,29 +224,38 @@ void close_intel_dialog(struct player *p)
   intel_destroy_callback(NULL, pdialog);
 }
 
+/**************************************************************************
+  Close an wonders list dialog for the given player.
+**************************************************************************/
+void close_intel_wonder_dialog(struct player *p)
+{
+  struct intel_wonder_dialog *pdialog = get_intel_wonder_dialog(p);
+
+  intel_wonder_destroy_callback(NULL, pdialog);
+}
+
 /****************************************************************
-  Create new intelligenze dialog between client user and player
+  Create new intelligence dialog between client user and player
   given as parameter.
 *****************************************************************/
 static struct intel_dialog *create_intel_dialog(struct player *p)
 {
   struct intel_dialog *pdialog;
 
-  GtkWidget *shell, *notebook, *label, *sw, *view, *table, *alignment;
+  GtkWidget *shell, *notebook, *label, *sw, *view, *table;
   GtkCellRenderer *rend;
   GtkTreeViewColumn *col;
-
   int i;
- 
+
   pdialog = fc_malloc(sizeof(*pdialog));
   pdialog->pplayer = p;
- 
+
   shell = gtk_dialog_new_with_buttons(NULL,
-      NULL,
-      0,
-      GTK_STOCK_CLOSE,
-      GTK_RESPONSE_CLOSE,
-      NULL);
+                                      NULL,
+                                      0,
+                                      _("_Close"),
+                                      GTK_RESPONSE_CLOSE,
+                                      NULL);
   pdialog->shell = shell;
   gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
   setup_dialog(shell, toplevel);
@@ -197,37 +268,33 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
 
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook), GTK_POS_BOTTOM);
-  gtk_container_add(GTK_CONTAINER(GTK_DIALOG(shell)->vbox), notebook);
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))), notebook);
  
   /* overview tab. */
-  table = gtk_table_new(ARRAY_SIZE(table_text), 2, FALSE);
+  table = gtk_grid_new();
+  g_object_set(table, "margin", 6, NULL);
 
-  gtk_table_set_row_spacings(GTK_TABLE(table), 2);
-  gtk_table_set_col_spacings(GTK_TABLE(table), 12);
-
-  alignment = gtk_alignment_new(0.0, 0.0, 0.0, 0.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), table);
+  gtk_grid_set_row_spacing(GTK_GRID(table), 2);
+  gtk_grid_set_column_spacing(GTK_GRID(table), 12);
 
   /* TRANS: Overview tab of foreign intelligence report dialog */
   label = gtk_label_new_with_mnemonic(_("_Overview"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table, label);
 
   for (i = 0; i < ARRAY_SIZE(table_text); i++) {
     if (table_text[i]) {
       label = gtk_label_new(_(table_text[i]));
-      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-      gtk_table_attach(GTK_TABLE(table), label,
-	  0, 1, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
+      gtk_widget_set_halign(label, GTK_ALIGN_START);
+      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+      gtk_grid_attach(GTK_GRID(table), label, 0, i, 1, 1);
 
       label = gtk_label_new(NULL);
       pdialog->table_labels[i] = label;
-      gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
-      gtk_table_attach(GTK_TABLE(table), label,
-	  1, 2, i, i+1, GTK_FILL, GTK_FILL|GTK_EXPAND, 0, 0);
+      gtk_widget_set_halign(label, GTK_ALIGN_START);
+      gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+      gtk_grid_attach(GTK_GRID(table), label, 1, i, 1, 1);
     } else {
       pdialog->table_labels[i] = NULL;
-      gtk_table_set_row_spacing(GTK_TABLE(table), i, 12);
     }
   }
 
@@ -235,6 +302,9 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   pdialog->diplstates = gtk_tree_store_new(1, G_TYPE_STRING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->diplstates));
+  g_object_set(view, "margin", 6, NULL);
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->diplstates);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -254,12 +324,8 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), sw);
-
   label = gtk_label_new_with_mnemonic(_("_Diplomacy"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
 
   /* techs tab. */
   pdialog->techs = gtk_list_store_new(2, G_TYPE_BOOLEAN, G_TYPE_STRING);
@@ -267,6 +333,9 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
       1, GTK_SORT_ASCENDING);
 
   view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->techs));
+  g_object_set(view, "margin", 6, NULL);
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
   g_object_unref(pdialog->techs);
   gtk_container_set_border_width(GTK_CONTAINER(view), 6);
   gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
@@ -289,20 +358,93 @@ static struct intel_dialog *create_intel_dialog(struct player *p)
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
 	GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  alignment = gtk_alignment_new(0.0, 0.0, 1.0, 1.0);
-  gtk_container_set_border_width(GTK_CONTAINER(alignment), 6);
-  gtk_container_add(GTK_CONTAINER(alignment), sw);
-
   label = gtk_label_new_with_mnemonic(_("_Techs"));
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), alignment, label);
+  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, label);
 
-  gtk_widget_show_all(GTK_DIALOG(shell)->vbox);
+  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(shell)));
 
   dialog_list_prepend(dialog_list, pdialog);
 
   return pdialog;
 }
 
+/**************************************************************************
+  Create new wonders list dialog between client user and player
+  given as parameter.
+**************************************************************************/
+static struct intel_wonder_dialog *create_intel_wonder_dialog(struct player *p)
+{
+  struct intel_wonder_dialog *pdialog;
+  GtkWidget *shell, *sw, *view;
+  GtkCellRenderer *rend;
+
+  pdialog = fc_malloc(sizeof(*pdialog));
+  pdialog->pplayer = p;
+
+  shell = gtk_dialog_new_with_buttons(NULL,
+                                      NULL,
+                                      0,
+                                      _("_Close"),
+                                      GTK_RESPONSE_CLOSE,
+                                      NULL);
+  pdialog->shell = shell;
+  gtk_window_set_default_size(GTK_WINDOW(shell), 350, 350);
+  setup_dialog(shell, toplevel);
+  gtk_dialog_set_default_response(GTK_DIALOG(shell), GTK_RESPONSE_CLOSE);
+
+  g_signal_connect(shell, "destroy",
+                   G_CALLBACK(intel_wonder_destroy_callback), pdialog);
+  g_signal_connect(shell, "response",
+                   G_CALLBACK(gtk_widget_destroy), NULL);
+
+  /* columns: 0 - wonder name, 1 - location (city/unknown/lost),
+   * 2 - strikethrough (for lost or obsolete),
+   * 3 - font weight (great wonders in bold) */
+  pdialog->wonders = gtk_list_store_new(4, G_TYPE_STRING,
+                                        G_TYPE_STRING,
+                                        G_TYPE_BOOLEAN,
+                                        G_TYPE_INT);
+  gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(pdialog->wonders),
+                                       3, GTK_SORT_DESCENDING);
+  view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pdialog->wonders));
+  g_object_set(view, "margin", 6, NULL);
+  gtk_widget_set_hexpand(view, TRUE);
+  gtk_widget_set_vexpand(view, TRUE);
+  g_object_unref(pdialog->wonders);
+  gtk_container_set_border_width(GTK_CONTAINER(view), 6);
+  gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(view), FALSE);
+
+  rend = gtk_cell_renderer_text_new();
+  gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, NULL,
+                                              rend, "text", 0,
+                                              "strikethrough", 2,
+                                              "weight", 3,
+                                              NULL);
+
+  rend = gtk_cell_renderer_text_new();
+  gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, NULL,
+                                              rend, "text", 1,
+                                              NULL);
+
+  sw = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
+                                      GTK_SHADOW_ETCHED_IN);
+  gtk_container_add(GTK_CONTAINER(sw), view);
+
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
+                                 GTK_POLICY_AUTOMATIC,
+                                 GTK_POLICY_AUTOMATIC);
+
+  gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(shell))),
+                    sw);
+
+  gtk_widget_show_all(gtk_dialog_get_content_area(GTK_DIALOG(shell)));
+
+  wonder_dialog_list_prepend(wonder_dialogs, pdialog);
+
+  return pdialog;
+}
+
 /****************************************************************************
   Update the intelligence dialog for the given player. This is called by
   the core client code when that player's information changes.
@@ -341,13 +483,13 @@ void update_intel_dialog(struct player *p)
       diplstates[i] = it;
     }
 
-    players_iterate_alive(other) {
+    players_iterate(other) {
       const struct player_diplstate *state;
       GtkTreeIter it;
       GValue v = { 0, };
 
-      if (other == p) {
-        continue;
+      if (other == p || !other->is_alive) {
+	continue;
       }
       state = player_diplstate_get(p, other);
       gtk_tree_store_append(pdialog->diplstates, &it,
@@ -356,7 +498,7 @@ void update_intel_dialog(struct player *p)
       g_value_set_static_string(&v, player_name(other));
       gtk_tree_store_set_value(pdialog->diplstates, &it, 0, &v);
       g_value_unset(&v);
-    } players_iterate_alive_end;
+    } players_iterate_end;
 
     /* techs tab. */
     gtk_list_store_clear(pdialog->techs);
@@ -473,4 +615,59 @@ void update_intel_dialog(struct player *p)
       }
     }
   }
+
+  /* Update also wonders list dialog */
+  update_intel_wonder_dialog(p);
+}
+
+/**********************************************************************//**
+  Update the wonders list dialog for the given player.
+**************************************************************************/
+void update_intel_wonder_dialog(struct player *p)
+{
+  struct intel_wonder_dialog *pdialog = get_intel_wonder_dialog(p);
+
+  if (pdialog != NULL) {
+    gchar *title = g_strdup_printf(_("Wonders of %s Empire"),
+                                   nation_adjective_for_player(p));
+
+    gtk_window_set_title(GTK_WINDOW(pdialog->shell), title);
+    g_free(title);
+
+    gtk_list_store_clear(pdialog->wonders);
+
+    improvement_iterate(impr) {
+      if (is_wonder(impr)) {
+        GtkTreeIter it;
+        const char *cityname;
+        bool is_lost = FALSE;
+
+        if (wonder_is_built(p, impr)) {
+          struct city *pcity = city_from_wonder(p, impr);
+          if (pcity) {
+            cityname = city_name_get(pcity);
+          } else {
+            cityname = _("(unknown city)");
+          }
+          if (improvement_obsolete(p, impr, NULL)) {
+            is_lost = TRUE;
+          }
+        } else if (wonder_is_lost(p, impr)) {
+          cityname = _("(lost)");
+          is_lost = TRUE;
+        } else {
+          continue;
+        }
+
+        gtk_list_store_append(pdialog->wonders, &it);
+        gtk_list_store_set(pdialog->wonders, &it,
+                           0, improvement_name_translation(impr),
+                           1, cityname,
+                           2, is_lost,
+                           /* font weight: great wonders in bold */
+                           3, is_great_wonder(impr) ? 700 : 400,
+                           -1);
+      }
+    } improvement_iterate_end;
+  }
 }
