@@ -359,14 +359,15 @@ void fc_client::switch_page(int new_pg)
       setWindowFlags(Qt::Window | Qt::CustomizeWindowHint);
     }
     showMaximized();
-    /* For MS Windows, it might ingore first */
+    /* For MS Windows, it might ignore first */
     showMaximized();
     gui()->infotab->chtwdg->update_widgets();
     status_bar->setVisible(false);
-    if (gui_options.gui_qt_fullscreen){
-      gui()->showFullScreen();
-      gui()->game_tab_widget->showFullScreen();
+
+    if (gui_options.gui_qt_fullscreen) {
+      apply_fullscreen();
     }
+
     menuBar()->setVisible(true);
     mapview_wdg->setFocus();
     center_on_something();
@@ -1036,6 +1037,7 @@ QString fc_icons::get_path(const QString &id)
 void fc_game_tab_widget::resizeEvent(QResizeEvent *event)
 {
   QSize size;
+
   size = event->size();
   if (C_S_RUNNING <= client_state()) {
     gui()->sidebar_wdg->resize_me(size.height());
@@ -1225,7 +1227,22 @@ void pregame_options::update_buttons()
   }
 }
 
-/************************************************************************//**
+/****************************************************************************
+  Apply current fullscreen option
+****************************************************************************/
+void fc_client::apply_fullscreen()
+{
+  if (gui_options.gui_qt_fullscreen) {
+    gui()->showFullScreen();
+    gui()->game_tab_widget->showFullScreen();
+  } else {
+    // FIXME: Doesn't return properly, probably something with sidebar
+    gui()->showNormal();
+    gui()->game_tab_widget->showNormal();
+  }
+}
+
+/****************************************************************************
   Updates the AI skill level control
 ****************************************************************************/
 void pregame_options::update_ai_level()
