@@ -1156,20 +1156,22 @@ void real_science_report_dialog_update(void *unused)
   bool blk = false;
   QWidget *w;
   QString str;
+  struct player *plr = client_player();
 
- if (NULL != client.conn.playing) {
-    struct research *research = research_get(client_player());
-  if (research->researching == A_UNSET) {
-      str = QString(_("none"));
-  } else if (research->client.researching_cost != 0) {
-    str = research_advance_name_translation(research,research->researching);
-    percent = 100 *research->bulbs_researched / research->client.researching_cost;
-    str = str + "\n (" + QString::number(percent) + "%)";
-  }
-  if (research->researching == A_UNSET && research->tech_goal == A_UNSET
-    && research->techs_researched < game.control.num_tech_types) {
-    blk = true;
-  }
+ if (NULL != plr) {
+   struct research *research = research_get(plr);
+
+   if (research->researching == A_UNSET) {
+     str = QString(Q_("?tech:None"));
+   } else if (research->client.researching_cost != 0) {
+     str = research_advance_name_translation(research,research->researching);
+     percent = 100 *research->bulbs_researched / research->client.researching_cost;
+     str = str + "\n (" + QString::number(percent) + "%)";
+   }
+   if (research->researching == A_UNSET && research->tech_goal == A_UNSET
+       && research->techs_researched < game.control.num_tech_types) {
+     blk = true;
+   }
  } else {
    str = " ";
  }
