@@ -276,7 +276,7 @@ void popup_connection_dialog(bool lan_scan)
   redraw_group(pNewWidget, pLabelWindow, TRUE);
   flush_dirty();
 
-  /* create server list */
+  /* Create server list */
   srvrs = sdl_create_server_list(lan_scan);
 
   /* Copy list */
@@ -316,8 +316,6 @@ void popup_connection_dialog(bool lan_scan)
   }
   pMeta_Server->pEndWidgetList = pWindow;
 
-  area = pWindow->area;
-
   /* Cancel button */
   pNewWidget = create_themeicon_button_from_chars(current_theme->CANCEL_Icon,
                                                   pWindow->dst, _("Cancel"),
@@ -326,7 +324,7 @@ void popup_connection_dialog(bool lan_scan)
   set_wstate(pNewWidget, FC_WS_NORMAL);
   add_to_gui_list(ID_BUTTON, pNewWidget);
 
-  /* servers */
+  /* Servers */
   server_list_iterate(pServer_list, pServer) {
 
     /* TRANS: "host.example.com Port 5556 Ver: 2.6.0 Running Players 3\n
@@ -335,7 +333,8 @@ void popup_connection_dialog(bool lan_scan)
                 pServer->host, pServer->port, pServer->version, _(pServer->state),
                 Q_("?header:Players"), pServer->nplayers, pServer->message);
 
-    pNewWidget = create_iconlabel_from_chars(NULL, pWindow->dst, cBuf, adj_font(10),
+    pNewWidget = create_iconlabel_from_chars_fonto(NULL, pWindow->dst, cBuf,
+                                                   FONTO_DEFAULT,
                      WF_FREE_STRING|WF_DRAW_TEXT_LABEL_WITH_SPACE|WF_RESTORE_BACKGROUND);
 
     pNewWidget->string_utf8->style |= SF_CENTER;
@@ -405,12 +404,12 @@ void popup_connection_dialog(bool lan_scan)
     w -= count;
   }
 
-  /* exit button */
+  /* Exit button */
   pNewWidget = pWindow->prev;
   pNewWidget->size.x = area.x + area.w - pNewWidget->size.w - adj_size(10);
   pNewWidget->size.y = area.y + area.h - pNewWidget->size.h - adj_size(10);
 
-  /* meta labels */
+  /* Meta labels */
   pNewWidget = pNewWidget->prev;
 
   pNewWidget->size.x = area.x + adj_size(10);
@@ -441,7 +440,7 @@ void popup_connection_dialog(bool lan_scan)
   }
 
   /* -------------------- */
-  /* redraw */
+  /* Redraw */
 
   widget_redraw(pWindow);
 
@@ -561,22 +560,22 @@ void popup_join_game_dialog(void)
 
   pConnectDlg = fc_calloc(1, sizeof(struct SMALL_DLG));
 
-  /* window */
+  /* Window */
   pWindow = create_window_skeleton(NULL, NULL, 0);
   add_to_gui_list(ID_WINDOW, pWindow);
   pConnectDlg->pEndWidgetList = pWindow;
 
   area = pWindow->area;
 
-  /* player name label */
-  plrname = create_utf8_from_char(_("Player Name :"), adj_font(10));
+  /* Player name label */
+  plrname = create_utf8_from_char_fonto(_("Player Name :"), FONTO_DEFAULT);
   plrname->fgcol = *get_theme_color(COLOR_THEME_JOINGAMEDLG_TEXT);
   pBuf = create_iconlabel(NULL, pWindow->dst, plrname,
           (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
   add_to_gui_list(ID_LABEL, pBuf);
   area.h += pBuf->size.h + adj_size(20);
 
-  /* player name edit */
+  /* Player name edit */
   pBuf = create_edit_from_chars(NULL, pWindow->dst, user_name, adj_font(14), adj_size(210),
                                 (WF_RESTORE_BACKGROUND|WF_FREE_DATA));
   pBuf->action = convert_playername_callback;
@@ -584,15 +583,15 @@ void popup_join_game_dialog(void)
   add_to_gui_list(ID_PLAYER_NAME_EDIT, pBuf);
   area.h += pBuf->size.h + adj_size(5);
 
-  /* server name label */
-  srvname = create_utf8_from_char(_("Freeciv Server :"), adj_font(10));
+  /* Server name label */
+  srvname = create_utf8_from_char_fonto(_("Freeciv Server :"), FONTO_DEFAULT);
   srvname->fgcol = *get_theme_color(COLOR_THEME_JOINGAMEDLG_TEXT);
   pBuf = create_iconlabel(NULL, pWindow->dst, srvname,
           (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
   add_to_gui_list(ID_LABEL, pBuf);
   area.h += pBuf->size.h + adj_size(5);
 
-  /* server name edit */
+  /* Server name edit */
   pBuf = create_edit_from_chars(NULL, pWindow->dst, server_host, adj_font(14), adj_size(210),
                                 WF_RESTORE_BACKGROUND);
 
@@ -601,15 +600,15 @@ void popup_join_game_dialog(void)
   add_to_gui_list(ID_SERVER_NAME_EDIT, pBuf);
   area.h += pBuf->size.h + adj_size(5);
 
-  /* port label */
-  port_nr = create_utf8_from_char(_("Port :"), adj_font(10));
+  /* Port label */
+  port_nr = create_utf8_from_char_fonto(_("Port :"), FONTO_DEFAULT);
   port_nr->fgcol = *get_theme_color(COLOR_THEME_JOINGAMEDLG_TEXT);
   pBuf = create_iconlabel(NULL, pWindow->dst, port_nr,
           (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
   add_to_gui_list(ID_LABEL, pBuf);
   area.h += pBuf->size.h + adj_size(5);
 
-  /* port edit */
+  /* Port edit */
   fc_snprintf(pCharPort, sizeof(pCharPort), "%d", server_port);
 
   pBuf = create_edit_from_chars(NULL, pWindow->dst, pCharPort, adj_font(14), adj_size(210),
@@ -797,15 +796,15 @@ static void popup_user_passwd_dialog(const char *pMessage)
 
   area = pWindow->area;
 
-  /* text label */
-  label_str = create_utf8_from_char(pMessage, adj_font(12));
+  /* Text label */
+  label_str = create_utf8_from_char_fonto(pMessage, FONTO_ATTENTION);
   label_str->fgcol = *get_theme_color(COLOR_THEME_USERPASSWDDLG_TEXT);
   pBuf = create_iconlabel(NULL, pWindow->dst, label_str,
                           (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
   add_to_gui_list(ID_LABEL, pBuf);
   area.h += adj_size(10) + pBuf->size.h + adj_size(5);
 
-  /* password edit */
+  /* Password edit */
   pBuf = create_edit(NULL, pWindow->dst, create_utf8_str(NULL, 0, adj_font(16)),
                      adj_size(210),
                      (WF_PASSWD_EDIT|WF_RESTORE_BACKGROUND|WF_FREE_DATA));
@@ -855,7 +854,7 @@ static void popup_user_passwd_dialog(const char *pMessage)
                       (main_window_width() - pWindow->size.w) / 2,
                       (main_window_height() - pWindow->size.h) / 2);
 
-  /* text label */
+  /* Text label */
   pBuf = pConnectDlg->pEndWidgetList->prev;
 
   start_x = area.x + (area.w - pBuf->size.w) / 2;
@@ -866,7 +865,7 @@ static void popup_user_passwd_dialog(const char *pMessage)
 
   start_y += pBuf->size.h + adj_size(5);
 
-  /* password edit */
+  /* Password edit */
   pBuf = pBuf->prev;
   start_x = area.x + (area.w - pBuf->size.w) / 2;
 
@@ -960,15 +959,15 @@ static void popup_new_user_passwd_dialog(const char *pMessage)
 
   area = pWindow->area;
 
-  /* text label */
-  label_str = create_utf8_from_char(pMessage, adj_font(12));
+  /* Text label */
+  label_str = create_utf8_from_char_fonto(pMessage, FONTO_ATTENTION);
   label_str->fgcol = *get_theme_color(COLOR_THEME_USERPASSWDDLG_TEXT);
   pBuf = create_iconlabel(NULL, pWindow->dst, label_str,
                           (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
   add_to_gui_list(ID_LABEL, pBuf);
   area.h += adj_size(10) + pBuf->size.h + adj_size(5);
 
-  /* password edit */
+  /* Password edit */
   pBuf = create_edit(NULL, pWindow->dst, create_utf8_str(NULL, 0, adj_font(16)),
                      adj_size(210),
                      (WF_PASSWD_EDIT|WF_RESTORE_BACKGROUND|WF_FREE_DATA));
@@ -977,7 +976,7 @@ static void popup_new_user_passwd_dialog(const char *pMessage)
   add_to_gui_list(ID_EDIT, pBuf);
   area.h += pBuf->size.h + adj_size(5);
 
-  /* second password edit */
+  /* Second password edit */
   pBuf = create_edit(NULL, pWindow->dst, create_utf8_str(NULL, 0, adj_font(16)),
                      adj_size(210),
                      (WF_PASSWD_EDIT|WF_RESTORE_BACKGROUND|WF_FREE_DATA));
