@@ -477,7 +477,8 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
   pCont->id0 = player_number(pPlayer0);
   pCont->id1 = player_number(pPlayer1);
 
-  pstr = create_utf8_from_char(nation_adjective_for_player(pPlayer0), adj_font(12));
+  pstr = create_utf8_from_char_fonto(nation_adjective_for_player(pPlayer0),
+                                     FONTO_ATTENTION);
   pstr->style |= TTF_STYLE_BOLD;
 
   pWindow = create_window_skeleton(NULL, pstr, WF_FREE_DATA);
@@ -497,8 +498,9 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
 
   /* Pacts. */
   if (pPlayer0 == client.conn.playing && DS_ALLIANCE != type) {
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       _("Pacts"), adj_font(12), WF_RESTORE_BACKGROUND);
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             _("Pacts"), FONTO_ATTENTION,
+                                             WF_RESTORE_BACKGROUND);
     pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
     width = pBuf->size.w;
     height = pBuf->size.h;
@@ -507,8 +509,9 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
 
     if (type != DS_CEASEFIRE && type != DS_TEAM) {
       fc_snprintf(cBuf, sizeof(cBuf), "  %s", Q_("?diplomatic_state:Cease-fire"));
-      pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-	cBuf, adj_font(12), (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
+      pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                               cBuf, FONTO_ATTENTION,
+                                               (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
       pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
       width = MAX(width, pBuf->size.w);
       height = MAX(height, pBuf->size.h);
@@ -522,8 +525,8 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     if (type != DS_PEACE && type != DS_TEAM) {
       fc_snprintf(cBuf, sizeof(cBuf), "  %s", Q_("?diplomatic_state:Peace"));
 
-      pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                         cBuf, adj_font(12),
+      pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                               cBuf, FONTO_ATTENTION,
                                          (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
       pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
       width = MAX(width, pBuf->size.w);
@@ -535,11 +538,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
       count++;
     }
 
-    if (pplayer_can_make_treaty(pPlayer0, pPlayer1, DS_ALLIANCE)) {
+    if (pplayer_can_make_treaty(pPlayer0, pPlayer1, DS_ALLIANCE) == DIPL_OK) {
       fc_snprintf(cBuf, sizeof(cBuf), "  %s", Q_("?diplomatic_state:Alliance"));
 
-      pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                         cBuf, adj_font(12),
+      pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                               cBuf, FONTO_ATTENTION,
                                          (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
       pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
       width = MAX(width, pBuf->size.w);
@@ -554,8 +557,9 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
 
   /* ---------------------------- */
   if (!gives_shared_vision(pPlayer0, pPlayer1)) {
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       _("Give shared vision"), adj_font(12),
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             _("Give shared vision"),
+                                             FONTO_ATTENTION,
      	                 (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
     pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
     width = MAX(width, pBuf->size.w);
@@ -567,10 +571,12 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     count++;
 
     /* ---------------------------- */
-    /* you can't give maps if you give shared vision */
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       _("Maps"), adj_font(12), WF_RESTORE_BACKGROUND);
-    pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
+    /* You can't give maps if you give shared vision */
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             _("Maps"), FONTO_ATTENTION,
+                                             WF_RESTORE_BACKGROUND);
+    pBuf->string_utf8->fgcol
+      = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
     width = MAX(width, pBuf->size.w);
     height = MAX(height, pBuf->size.h);
     add_to_gui_list(ID_LABEL, pBuf);
@@ -579,9 +585,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     /* ----- */
     fc_snprintf(cBuf, sizeof(cBuf), "  %s", _("World map"));
 
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-	cBuf, adj_font(12), (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
-    pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             cBuf, FONTO_ATTENTION,
+                                             (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
+    pBuf->string_utf8->fgcol
+      = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
     width = MAX(width, pBuf->size.w);
     height = MAX(height, pBuf->size.h);
     pBuf->action = maps_callback;
@@ -593,10 +601,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     /* ----- */
     fc_snprintf(cBuf, sizeof(cBuf), "  %s", _("Sea map"));
 
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       cBuf, adj_font(12),
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             cBuf, FONTO_ATTENTION,
                                        (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
-    pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+    pBuf->string_utf8->fgcol
+      = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
     width = MAX(width, pBuf->size.w);
     height = MAX(height, pBuf->size.h);
     pBuf->action = maps_callback;
@@ -608,8 +617,8 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
 
   /* Don't take in account the embassy effects. */
   if (!player_has_real_embassy(pPlayer1, pPlayer0)) {
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       _("Give embassy"), adj_font(12),
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             _("Give embassy"), FONTO_ATTENTION,
                                        (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
     pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
     width = MAX(width, pBuf->size.w);
@@ -626,16 +635,18 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     pCont->value = pPlayer0->economic.gold;
 
     fc_snprintf(cBuf, sizeof(cBuf), _("Gold(max %d)"), pPlayer0->economic.gold);
-    pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                       cBuf, adj_font(12), WF_RESTORE_BACKGROUND);
-    pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
+    pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                             cBuf, FONTO_ATTENTION,
+                                             WF_RESTORE_BACKGROUND);
+    pBuf->string_utf8->fgcol
+      = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
     width = MAX(width, pBuf->size.w);
     height = MAX(height, pBuf->size.h);
     add_to_gui_list(ID_LABEL, pBuf);
     count++;
 
     pBuf = create_edit(NULL, pWindow->dst,
-                       create_utf8_from_char("0", adj_font(10)), 0,
+                       create_utf8_from_char_fonto("0", FONTO_DEFAULT), 0,
                        (WF_RESTORE_BACKGROUND|WF_FREE_STRING));
     pBuf->data.cont = pCont;
     pBuf->action = gold_callback;
@@ -661,10 +672,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
               || research_invention_state(presearch1, i)
                  == TECH_PREREQS_KNOWN)) {
 
-        pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                           _("Advances"), adj_font(12),
-                                           WF_RESTORE_BACKGROUND);
-        pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
+        pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                                 _("Advances"), FONTO_ATTENTION,
+                                                 WF_RESTORE_BACKGROUND);
+        pBuf->string_utf8->fgcol
+          = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
         width = MAX(width, pBuf->size.w);
         height = MAX(height, pBuf->size.h);
         add_to_gui_list(ID_LABEL, pBuf);
@@ -673,9 +685,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
         fc_snprintf(cBuf, sizeof(cBuf), "  %s",
                     advance_name_translation(advance_by_number(i)));
 
-        pBuf = create_iconlabel_from_chars(NULL, pWindow->dst, cBuf, adj_font(12),
+        pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst, cBuf,
+                                                 FONTO_ATTENTION,
                                            (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
-        pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+        pBuf->string_utf8->fgcol
+          = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
         width = MAX(width, pBuf->size.w);
         height = MAX(height, pBuf->size.h);
         pBuf->action = techs_callback;
@@ -700,9 +714,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
           fc_snprintf(cBuf, sizeof(cBuf), "  %s",
                       advance_name_translation(advance_by_number(i)));
 
-          pBuf = create_iconlabel_from_chars(NULL, pWindow->dst, cBuf, adj_font(12),
+          pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst, cBuf,
+                                                   FONTO_ATTENTION,
                               (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
-          pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+          pBuf->string_utf8->fgcol
+            = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
           width = MAX(width, pBuf->size.w);
           height = MAX(height, pBuf->size.h);
           pBuf->action = techs_callback;
@@ -740,10 +756,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
     }
 
     if (i > 0) {
-      pBuf = create_iconlabel_from_chars(NULL, pWindow->dst,
-                                         _("Cities"), adj_font(12),
-                                         WF_RESTORE_BACKGROUND);
-      pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
+      pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst,
+                                               _("Cities"), FONTO_ATTENTION,
+                                               WF_RESTORE_BACKGROUND);
+      pBuf->string_utf8->fgcol
+        = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_HEADING_TEXT);
       pBuf->string_utf8->style &= ~SF_CENTER;
       width = MAX(width, pBuf->size.w);
       height = MAX(height, pBuf->size.h);
@@ -755,9 +772,11 @@ static struct ADVANCED_DLG *popup_diplomatic_objects(struct player *pPlayer0,
       for (j = 0; j < i; j++) {
         fc_snprintf(cBuf, sizeof(cBuf), "  %s", city_name_get(city_list_ptrs[j]));
 
-        pBuf = create_iconlabel_from_chars(NULL, pWindow->dst, cBuf, adj_font(12),
+        pBuf = create_iconlabel_from_chars_fonto(NULL, pWindow->dst, cBuf,
+                                                 FONTO_ATTENTION,
                             (WF_RESTORE_BACKGROUND|WF_DRAW_TEXT_LABEL_WITH_SPACE));
-        pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+        pBuf->string_utf8->fgcol
+          = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
         width = MAX(width, pBuf->size.w);
         height = MAX(height, pBuf->size.h);
         pBuf->data.cont = pCont;
@@ -883,7 +902,7 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
 
     fc_snprintf(cBuf, sizeof(cBuf), _("Diplomacy meeting"));
 
-    pstr = create_utf8_from_char(cBuf, adj_font(12));
+    pstr = create_utf8_from_char_fonto(cBuf, FONTO_ATTENTION);
     pstr->style |= TTF_STYLE_BOLD;
 
     pWindow = create_window_skeleton(NULL, pstr, 0);
@@ -897,7 +916,8 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
 
     /* ============================================================= */
 
-    pstr = create_utf8_from_char(nation_adjective_for_player(pPlayer0), adj_font(12));
+    pstr = create_utf8_from_char_fonto(nation_adjective_for_player(pPlayer0),
+                                       FONTO_ATTENTION);
     pstr->style |= (TTF_STYLE_BOLD|SF_CENTER);
     pstr->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
 
@@ -913,7 +933,8 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
 
     add_to_gui_list(ID_ICON, pBuf);
 
-    pstr = create_utf8_from_char(nation_adjective_for_player(pPlayer1), adj_font(12));
+    pstr = create_utf8_from_char_fonto(nation_adjective_for_player(pPlayer1),
+                                       FONTO_ATTENTION);
     pstr->style |= (TTF_STYLE_BOLD|SF_CENTER);
     pstr->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
 
@@ -931,8 +952,8 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
     pBuf = create_themeicon(current_theme->CANCEL_PACT_Icon, pWindow->dst,
                             WF_WIDGET_HAS_INFO_LABEL
                             | WF_RESTORE_BACKGROUND);
-    pBuf->info_label = create_utf8_from_char(_("Cancel meeting"),
-                                             adj_font(12));
+    pBuf->info_label = create_utf8_from_char_fonto(_("Cancel meeting"),
+                                                   FONTO_ATTENTION);
     pBuf->action = cancel_meeting_callback;
     pBuf->data.cont = pCont;
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -942,8 +963,8 @@ static void update_diplomacy_dialog(struct diplomacy_dialog *pdialog)
     pBuf = create_themeicon(current_theme->OK_PACT_Icon, pWindow->dst,
                             WF_FREE_DATA | WF_WIDGET_HAS_INFO_LABEL
                             |WF_RESTORE_BACKGROUND);
-    pBuf->info_label = create_utf8_from_char(_("Accept treaty"),
-                                             adj_font(12));
+    pBuf->info_label = create_utf8_from_char_fonto(_("Accept treaty"),
+                                                   FONTO_ATTENTION);
     pBuf->action = accept_treaty_callback;
     pBuf->data.cont = pCont;
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -1077,7 +1098,7 @@ static void update_clauses_list(struct diplomacy_dialog *pdialog)
   clause_list_iterate(pdialog->treaty.clauses, pclause) {
     client_diplomacy_clause_string(cBuf, sizeof(cBuf), pclause);
 
-    pstr = create_utf8_from_char(cBuf, adj_font(12));
+    pstr = create_utf8_from_char_fonto(cBuf, FONTO_ATTENTION);
     pbuf = create_iconlabel(NULL, pWindow->dst, pstr,
      (WF_FREE_DATA|WF_DRAW_TEXT_LABEL_WITH_SPACE|WF_RESTORE_BACKGROUND));
 
@@ -1373,7 +1394,7 @@ static void popup_war_dialog(struct player *pPlayer)
               /* TRANS: "Polish incident !" FIXME!!! */
               _("%s incident !"),
               nation_adjective_for_player(pPlayer));
-  pstr = create_utf8_from_char(cBuf, adj_font(12));
+  pstr = create_utf8_from_char_fonto(cBuf, FONTO_ATTENTION);
   pstr->style |= TTF_STYLE_BOLD;
 
   pWindow = create_window_skeleton(NULL, pstr, 0);
@@ -1388,7 +1409,7 @@ static void popup_war_dialog(struct player *pPlayer)
   area = pWindow->area;
 
   /* ============================================================= */
-  /* label */
+  /* Label */
   fc_snprintf(cBuf, sizeof(cBuf), _("Shall we declare WAR on them?"));
 
   pstr = create_utf8_from_char(cBuf, adj_font(14));
@@ -1400,9 +1421,9 @@ static void popup_war_dialog(struct player *pPlayer)
   area.w = MAX(area.w, pText->w);
   area.h += pText->h + adj_size(10);
 
-  pBuf = create_themeicon_button_from_chars(current_theme->CANCEL_Icon,
-                                            pWindow->dst, _("No"),
-                                            adj_font(12), 0);
+  pBuf = create_themeicon_button_from_chars_fonto(current_theme->CANCEL_Icon,
+                                                  pWindow->dst, _("No"),
+                                                  FONTO_ATTENTION, 0);
 
   pBuf->action = cancel_sdip_dlg_callback;
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -1411,8 +1432,10 @@ static void popup_war_dialog(struct player *pPlayer)
 
   add_to_gui_list(ID_BUTTON, pBuf);
 
-  pBuf = create_themeicon_button_from_chars(current_theme->OK_Icon, pWindow->dst,
-                                            _("Yes"), adj_font(12), 0);
+  pBuf = create_themeicon_button_from_chars_fonto(current_theme->OK_Icon,
+                                                  pWindow->dst,
+                                                  _("Yes"),
+                                                  FONTO_ATTENTION, 0);
 
   pBuf->action = cancel_pact_dlg_callback;
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -1425,11 +1448,8 @@ static void popup_war_dialog(struct player *pPlayer)
 
   pSDip_Dlg->pBeginWidgetList = pBuf;
 
-  /* setup window size and start position */
+  /* Setup window size and start position */
   area.w += adj_size(10);
-
-  pBuf = pWindow->prev;
-
   area.h += adj_size(5);
 
   resize_window(pWindow, NULL, get_theme_color(COLOR_THEME_BACKGROUND),
@@ -1442,8 +1462,8 @@ static void popup_war_dialog(struct player *pPlayer)
                       (main_window_width() - pWindow->size.w) / 2,
                       (main_window_height() - pWindow->size.h) / 2);
 
-  /* setup rest of widgets */
-  /* label */
+  /* Setup rest of widgets */
+  /* Label */
   dst.x = area.x + (area.w - pText->w) / 2;
   dst.y = area.y + 1;
   alphablit(pText, NULL, pWindow->theme, &dst, 255);
@@ -1507,8 +1527,8 @@ void popup_diplomacy_dialog(struct player *pPlayer)
 
     pSDip_Dlg = fc_calloc(1, sizeof(struct SMALL_DLG));
 
-    fc_snprintf(cBuf, sizeof(cBuf),  _("Foreign Minister"));
-    pstr = create_utf8_from_char(cBuf, adj_font(12));
+    fc_snprintf(cBuf, sizeof(cBuf), _("Foreign Minister"));
+    pstr = create_utf8_from_char_fonto(cBuf, FONTO_ATTENTION);
     pstr->style |= TTF_STYLE_BOLD;
 
     pWindow = create_window_skeleton(NULL, pstr, 0);
@@ -1522,7 +1542,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     area = pWindow->area;
 
     /* ============================================================= */
-    /* label */
+    /* Label */
     if (client.conn.playing == NULL || client.conn.playing->is_male) {
       fc_snprintf(cBuf, sizeof(cBuf), _("Sir!, the %s ambassador has arrived\n"
                                         "What are your wishes?"),
@@ -1547,19 +1567,20 @@ void popup_diplomacy_dialog(struct player *pPlayer)
 
     if (can_toward_war) {
       if (type == DS_ARMISTICE) {
-	fc_snprintf(cBuf, sizeof(cBuf), _("Declare WAR"));
+        fc_snprintf(cBuf, sizeof(cBuf), _("Declare WAR"));
       } else {
-	fc_snprintf(cBuf, sizeof(cBuf), _("Cancel Treaty"));
+        fc_snprintf(cBuf, sizeof(cBuf), _("Cancel Treaty"));
       }
 
-      /* cancel treaty */
-      pBuf = create_themeicon_button_from_chars(current_theme->UNITS2_Icon,
-                                                pWindow->dst, cBuf,
-                                                adj_font(12), 0);
+      /* Cancel treaty */
+      pBuf = create_themeicon_button_from_chars_fonto(current_theme->UNITS2_Icon,
+                                                      pWindow->dst, cBuf,
+                                                      FONTO_ATTENTION, 0);
 
       pBuf->action = cancel_pact_dlg_callback;
       set_wstate(pBuf, FC_WS_NORMAL);
-      pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+      pBuf->string_utf8->fgcol
+        = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
       pBuf->data.player = pPlayer;
       pBuf->key = SDLK_c;
       add_to_gui_list(ID_BUTTON, pBuf);
@@ -1573,16 +1594,18 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     shared = gives_shared_vision(client.conn.playing, pPlayer);
 
     if (shared) {
-      /* shared vision */
-      pBuf = create_themeicon_button_from_chars(current_theme->UNITS2_Icon,
-                                                pWindow->dst, _("Withdraw vision"),
-                                                adj_font(12), 0);
+      /* Shared vision */
+      pBuf = create_themeicon_button_from_chars_fonto(current_theme->UNITS2_Icon,
+                                                      pWindow->dst,
+                                                      _("Withdraw vision"),
+                                                      FONTO_ATTENTION, 0);
 
       pBuf->action = withdraw_vision_dlg_callback;
       set_wstate(pBuf, FC_WS_NORMAL);
       pBuf->data.player = pPlayer;
       pBuf->key = SDLK_w;
-      pBuf->string_utf8->fgcol = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
+      pBuf->string_utf8->fgcol
+        = *get_theme_color(COLOR_THEME_DIPLODLG_MEETING_TEXT);
       add_to_gui_list(ID_BUTTON, pBuf);
       pBuf->size.w = MAX(pBuf->next->size.w, pBuf->size.w);
       pBuf->next->size.w = pBuf->size.w;
@@ -1591,11 +1614,11 @@ void popup_diplomacy_dialog(struct player *pPlayer)
       buttons++;
     }
 
-    /* meet */
-    pBuf = create_themeicon_button_from_chars(current_theme->PLAYERS_Icon,
-                                              pWindow->dst,
-                                              _("Call Diplomatic Meeting"),
-                                              adj_font(12), 0);
+    /* Meet */
+    pBuf = create_themeicon_button_from_chars_fonto(current_theme->PLAYERS_Icon,
+                                                    pWindow->dst,
+                                                    _("Call Diplomatic Meeting"),
+                                                    FONTO_ATTENTION, 0);
 
     pBuf->action = call_meeting_dlg_callback;
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -1609,9 +1632,10 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     button_h = MAX(button_h , pBuf->size.h);
     buttons++;
 
-    pBuf = create_themeicon_button_from_chars(current_theme->CANCEL_Icon,
-                                              pWindow->dst, _("Send him back"),
-                                              adj_font(12), 0);
+    pBuf = create_themeicon_button_from_chars_fonto(current_theme->CANCEL_Icon,
+                                                    pWindow->dst,
+                                                    _("Send him back"),
+                                                    FONTO_ATTENTION, 0);
 
     pBuf->action = cancel_sdip_dlg_callback;
     set_wstate(pBuf, FC_WS_NORMAL);
@@ -1630,11 +1654,8 @@ void popup_diplomacy_dialog(struct player *pPlayer)
 
     pSDip_Dlg->pBeginWidgetList = pBuf;
 
-    /* setup window size and start position */
+    /* Setup window size and start position */
     area.w += adj_size(10);
-
-    pBuf = pWindow->prev;
-
     area.h += adj_size(2);
 
     resize_window(pWindow, NULL, get_theme_color(COLOR_THEME_BACKGROUND),
@@ -1647,8 +1668,8 @@ void popup_diplomacy_dialog(struct player *pPlayer)
                         (main_window_width() - pWindow->size.w) / 2,
                         (main_window_height() - pWindow->size.h) / 2);
 
-    /* setup rest of widgets */
-    /* label */
+    /* Setup rest of widgets */
+    /* Label */
     dst.x = area.x + (area.w - pText->w) / 2;
     dst.y = area.y + 1;
     alphablit(pText, NULL, pWindow->theme, &dst, 255);
@@ -1657,7 +1678,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
 
     pBuf = pWindow;
 
-    /* war: meet, peace: cancel treaty */
+    /* War: meet, peace: cancel treaty */
     pBuf = pBuf->prev;
     pBuf->size.w = button_w;
     pBuf->size.h = button_h;
@@ -1665,7 +1686,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     pBuf->size.y = dst.y;
 
     if (shared) {
-      /* vision */
+      /* Vision */
       pBuf = pBuf->prev;
       pBuf->size.w = button_w;
       pBuf->size.h = button_h;
@@ -1674,7 +1695,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     }
 
     if (type != DS_WAR) {
-      /* meet */
+      /* Meet */
       pBuf = pBuf->prev;
       pBuf->size.w = button_w;
       pBuf->size.h = button_h;
@@ -1682,7 +1703,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
       pBuf->size.x = pBuf->next->size.x;
     }
 
-    /* cancel */
+    /* Cancel */
     if (can_toward_war) {
       pBuf = pBuf->prev;
       pBuf->size.w = button_w;
@@ -1692,7 +1713,7 @@ void popup_diplomacy_dialog(struct player *pPlayer)
     }
 
     /* ================================================== */
-    /* redraw */
+    /* Redraw */
     redraw_group(pSDip_Dlg->pBeginWidgetList, pWindow, 0);
     widget_mark_dirty(pWindow);
 
