@@ -597,7 +597,8 @@ bool set_video_mode(int width, int height, int flags_in)
     return FALSE;
   }
 
-  if (gui_options.gui_sdl2_swrenderer) {
+  if (gui_options.gui_sdl2_swrenderer
+      || (SDL_Client_Flags & CF_SWRENDERER)) {
     flags = SDL_RENDERER_SOFTWARE;
   } else {
     flags = 0;
@@ -767,7 +768,6 @@ static int __FillRectAlpha565(SDL_Surface *pSurface, SDL_Rect *pRect,
         start = pixel;
       }
     } else {
-      y = 0;
       S = (S | S << 16) & 0x07e0f81f;
       y = pRect->h;
       end = pRect->w;
@@ -1235,7 +1235,7 @@ static int __FillRectAlpha888_24bit(SDL_Surface *pSurface, SDL_Rect *pRect,
 
       P = P | D;
 
-      /* Fix me to little - big EDIAN */
+      /* Fix me to little - big ENDIAN */
 
       pixel[0] = P & 0xff;
       pixel[1] = (P >> 8) & 0xff;
@@ -1282,7 +1282,7 @@ static int __FillRectAlpha888_24bit(SDL_Surface *pSurface, SDL_Rect *pRect,
 
       P = P | D;
 
-      /* Fix me to little - big EDIAN */
+      /* Fix me to little - big ENDIAN */
 
       pixel[0] = P & 0xff;
       pixel[1] = (P >> 8) & 0xff;
@@ -1382,7 +1382,7 @@ bool correct_rect_region(SDL_Rect *pRect)
   /* End Correction */
 
   if (ww <= 0 || hh <= 0) {
-    return FALSE; /* suprise :) */
+    return FALSE; /* surprise :) */
   } else {
     pRect->w = ww;
     pRect->h = hh;
