@@ -164,9 +164,10 @@ struct callback_list *callbacks = NULL;
 **************************************************************************/
 static void print_usage(void)
 {
-  /* add client-specific usage information here */
+  /* Add client-specific usage information here */
   fc_fprintf(stderr,
              _("  -f,  --fullscreen\tStart Client in Fullscreen mode\n"));
+  fc_fprintf(stderr, _("  -s,  --swrenderer\tUse SW renderer\n"));
   fc_fprintf(stderr, _("  -t,  --theme THEME\tUse GUI theme THEME\n"));
 
   /* TRANS: No full stop after the URL, could cause confusion. */
@@ -187,6 +188,8 @@ static void parse_options(int argc, char **argv)
       exit(EXIT_SUCCESS);
     } else if (is_option("--fullscreen", argv[i])) {
       gui_options.gui_sdl2_fullscreen = TRUE;
+    } else if (is_option("--swrenderer", argv[i])) {
+      SDL_Client_Flags |= CF_SWRENDERER;
     } else if ((option = get_option_malloc("--theme", argv, &i, argc, FALSE))) {
       sz_strlcpy(gui_options.gui_sdl2_default_theme_name, option);
       free(option);
@@ -1238,6 +1241,15 @@ void gui_update_font(const char *font_name, const char *font_value)
 #undef CHECK_FONT
 }
 
+/**************************************************************************
+  Update font sizes based on theme.
+**************************************************************************/
+void update_font_from_theme(int theme_font_size)
+{
+  *client_font_sizes[FONT_CITY_NAME] = theme_font_size;
+  *client_font_sizes[FONT_CITY_PROD] = theme_font_size;
+}
+
 /**************************************************************************
   Insert build information to help
 **************************************************************************/
