@@ -359,7 +359,8 @@ void popup_players_dialog(bool raise)
 
   pPlayers_Dlg = fc_calloc(1, sizeof(struct SMALL_DLG));
 
-  pstr = create_utf8_from_char(Q_("?header:Players"), adj_font(12));
+  pstr = create_utf8_from_char_fonto(Q_("?header:Players"),
+                                     FONTO_ATTENTION);
   pstr->style |= TTF_STYLE_BOLD;
 
   pWindow = create_window_skeleton(NULL, pstr, 0);
@@ -370,11 +371,11 @@ void popup_players_dialog(bool raise)
   add_to_gui_list(ID_WINDOW, pWindow);
   pPlayers_Dlg->pEndWidgetList = pWindow;
   /* ---------- */
-  /* exit button */
+  /* Exit button */
   pBuf = create_themeicon(current_theme->Small_CANCEL_Icon, pWindow->dst,
                           WF_WIDGET_HAS_INFO_LABEL | WF_RESTORE_BACKGROUND);
-  pBuf->info_label = create_utf8_from_char(_("Close Dialog (Esc)"),
-                                           adj_font(12));
+  pBuf->info_label = create_utf8_from_char_fonto(_("Close Dialog (Esc)"),
+                                                 FONTO_ATTENTION);
   pBuf->action = exit_players_dlg_callback;
   set_wstate(pBuf, FC_WS_NORMAL);
   pBuf->key = SDLK_ESCAPE;
@@ -434,7 +435,7 @@ void popup_players_dialog(bool raise)
       continue;
     }
 
-    pstr = create_utf8_str(NULL, 0, adj_font(10));
+    pstr = create_utf8_str_fonto(NULL, 0, FONTO_DEFAULT);
     pstr->style |= (TTF_STYLE_BOLD|SF_CENTER);
 
     pLogo = get_nation_flag_surface(nation_of_player(pPlayer));
@@ -452,7 +453,7 @@ void popup_players_dialog(bool raise)
     pBuf->info_label = pstr;
 
     if (!pPlayer->is_alive) {
-      pstr = create_utf8_from_char(_("R.I.P.") , adj_font(10));
+      pstr = create_utf8_from_char_fonto(_("R.I.P."), FONTO_DEFAULT);
       pstr->style |= TTF_STYLE_BOLD;
       pstr->fgcol = *get_theme_color(COLOR_THEME_PLRDLG_TEXT);
       pLogo = create_text_surf_from_utf8(pstr);
@@ -498,7 +499,7 @@ void popup_players_dialog(bool raise)
   pBuf->size.y = pWindow->size.y + adj_size(2);
 
   n = area.y;
-  pstr = create_utf8_str(NULL, 0, adj_font(10));
+  pstr = create_utf8_str_fonto(NULL, 0, FONTO_DEFAULT);
   pstr->style |= TTF_STYLE_BOLD;
   pstr->bgcol = (SDL_Color) {0, 0, 0, 0};
 
@@ -677,7 +678,7 @@ void popup_players_nations_dialog(void)
   pShort_Players_Dlg = fc_calloc(1, sizeof(struct ADVANCED_DLG));
 
   /* TRANS: Nations report title */
-  pstr = create_utf8_from_char(_("Nations") , adj_font(12));
+  pstr = create_utf8_from_char_fonto(_("Nations"), FONTO_ATTENTION);
   pstr->style |= TTF_STYLE_BOLD;
 
   pWindow = create_window_skeleton(NULL, pstr, 0);
@@ -691,11 +692,11 @@ void popup_players_nations_dialog(void)
   area = pWindow->area;
 
   /* ---------- */
-  /* exit button */
+  /* Exit button */
   pBuf = create_themeicon(current_theme->Small_CANCEL_Icon, pWindow->dst,
                           WF_WIDGET_HAS_INFO_LABEL | WF_RESTORE_BACKGROUND);
-  pBuf->info_label = create_utf8_from_char(_("Close Dialog (Esc)"),
-                                           adj_font(12));
+  pBuf->info_label = create_utf8_from_char_fonto(_("Close Dialog (Esc)"),
+                                                 FONTO_ATTENTION);
   area.w = MAX(area.w, pBuf->size.w + adj_size(10));
   pBuf->action = exit_players_nations_dlg_callback;
   set_wstate(pBuf, FC_WS_NORMAL);
@@ -739,7 +740,7 @@ void popup_players_nations_dialog(void)
                     state);
       }
 
-      pstr = create_utf8_from_char(cBuf, adj_font(10));
+      pstr = create_utf8_from_char_fonto(cBuf, FONTO_DEFAULT);
       pstr->style |= TTF_STYLE_BOLD;
 
       pLogo = get_nation_flag_surface(nation_of_player(pPlayer));
