@@ -214,17 +214,18 @@ void citylog_map_workers(enum log_level level, struct city *pcity);
   } city_map_iterate_end;						\
 }
 
-/* Does the same thing as city_tile_iterate_index, but keeps the city
+/* Does the same thing as city_tile_iterate_index(), but keeps the city
  * coordinates hidden. */
 #define city_tile_iterate(_radius_sq, _city_tile, _tile) {              \
-  city_map_iterate_outwards_radius_sq(CITY_MAP_CENTER_RADIUS_SQ,	\
-                                      _radius_sq, _x, _y)	        \
-  struct tile *_tile = city_map_to_tile(_city_tile, _radius_sq,         \
-                                        _x, _y);			\
+  const struct tile *_center##_tile = _city_tile;                       \
+  city_map_iterate_outwards_radius_sq(CITY_MAP_CENTER_RADIUS_SQ,        \
+                                      _radius_sq, _x, _y)               \
+  struct tile *_tile = city_map_to_tile(_center##_tile, _radius_sq,     \
+                                        _x, _y);                        \
   if (NULL != _tile) {
 
-#define city_tile_iterate_end					        \
-    }									\
+#define city_tile_iterate_end                                           \
+    }                                                                   \
   } city_map_iterate_outwards_radius_sq_end;
 
 /* Improvement status (for cities' lists of improvements)
@@ -497,15 +498,16 @@ extern struct output_type output_types[];
                                                                        \
   if (_city##_size > 0) {                                              \
     int _city##_numbers[_city##_size];                                 \
-    int _city##_index = 0;                                             \
+    int _city##_index;                                                 \
                                                                        \
+    _city##_size = 0;                                                  \
     city_list_iterate(_city##_cl, _city) {                             \
-      _city##_numbers[_city##_index++] = _city->id;                    \
+      _city##_numbers[_city##_size++] = _city->id;                     \
     } city_list_iterate_end;                                           \
                                                                        \
     for (_city##_index = 0;                                            \
-        _city##_index < _city##_size;                                  \
-        _city##_index++) {                                             \
+         _city##_index < _city##_size;                                 \
+         _city##_index++) {                                            \
       struct city *_city =                                             \
         game_city_by_number(_city##_numbers[_city##_index]);           \
                                                                        \
