@@ -24,6 +24,16 @@ struct packet_processing_finished {
   char __dummy;			/* to avoid malloc(0); */
 };
 
+struct packet_investigate_started {
+  int unit_id;
+  int city_id;
+};
+
+struct packet_investigate_finished {
+  int unit_id;
+  int city_id;
+};
+
 struct packet_server_join_req {
   char username[48];
   char capability[512];
@@ -1377,7 +1387,8 @@ struct packet_ruleset_control {
   bool popup_tech_help;
   char name[MAX_LEN_NAME];
   char version[MAX_LEN_NAME];
-  int desc_length;
+  int desc_length16;
+  int desc_length32;
 };
 
 struct packet_ruleset_summary {
@@ -1780,6 +1791,8 @@ enum packet_type {
   PACKET_MAP_INFO,
   PACKET_NUKE_TILE_INFO,
   PACKET_TEAM_NAME_INFO,
+  PACKET_INVESTIGATE_STARTED = 21,
+  PACKET_INVESTIGATE_FINISHED,
   PACKET_CHAT_MSG = 25,
   PACKET_CHAT_MSG_REQ,
   PACKET_CONNECT_MSG,
@@ -1957,6 +1970,12 @@ int send_packet_processing_started(struct connection *pc);
 
 int send_packet_processing_finished(struct connection *pc);
 
+int send_packet_investigate_started(struct connection *pc, const struct packet_investigate_started *packet);
+int dsend_packet_investigate_started(struct connection *pc, int unit_id, int city_id);
+
+int send_packet_investigate_finished(struct connection *pc, const struct packet_investigate_finished *packet);
+int dsend_packet_investigate_finished(struct connection *pc, int unit_id, int city_id);
+
 int send_packet_server_join_req(struct connection *pc, const struct packet_server_join_req *packet);
 int dsend_packet_server_join_req(struct connection *pc, const char *username, const char *capability, const char *version_label, int major_version, int minor_version, int patch_version);
 
