@@ -1448,9 +1448,18 @@ bool is_my_zoc(const struct player *pplayer, const struct tile *ptile0)
       }
     } else {
       unit_list_iterate(ptile->units, punit) {
-        if (!pplayers_allied(unit_owner(punit), pplayer)
-            && !unit_has_type_flag(punit, UTYF_NOZOC)) {
-          return FALSE;
+        if (srv) {
+          if (!unit_transported_server(punit)
+              && !pplayers_allied(unit_owner(punit), pplayer)
+              && !unit_has_type_flag(punit, UTYF_NOZOC)) {
+            return FALSE;
+          }
+        } else {
+          if (!unit_transported_client(punit)
+              && !pplayers_allied(unit_owner(punit), pplayer)
+              && !unit_has_type_flag(punit, UTYF_NOZOC)) {
+            return FALSE;
+          }
         }
       } unit_list_iterate_end;
     }
@@ -2285,12 +2294,11 @@ bool unit_transported(const struct unit *pcargo)
 
   /* The unit is transported if a transporter unit is set or, (for the client)
    * if the transported_by field is set. */
-  if (pcargo->transporter != NULL
-      || (!is_server() && pcargo->client.transported_by != -1)) {
-    return TRUE;
+  if (is_server()) {
+    return unit_transported_server(pcargo);
+  } else {
+    return unit_transported_client(pcargo);
   }
-
-  return FALSE;
 }
 
 /*****************************************************************************
@@ -2440,18 +2448,20 @@ static void *cargo_iter_get(const struct iterator *it)
 static void cargo_iter_next(struct iterator *it)
 {
   struct cargo_iter *iter = CARGO_ITER(it);
-  const struct unit_list_link *piter = iter->links[iter->depth - 1];
+  const struct unit_list_link *piter;
   const struct unit_list_link *pnext;
 
   /* Variant 1: unit has cargo. */
-  pnext = unit_list_head(unit_transport_cargo(unit_list_link_data(piter)));
+  pnext = unit_list_head(unit_transport_cargo(cargo_iter_get(it)));
   if (NULL != pnext) {
     fc_assert(iter->depth < ARRAY_SIZE(iter->links));
     iter->links[iter->depth++] = pnext;
     return;
   }
 
-  do {
+  while (iter->depth > 0) {
+    piter = iter->links[iter->depth - 1];
+
     /* Variant 2: there are other cargo units at same level. */
     pnext = unit_list_link_next(piter);
     if (NULL != pnext) {
@@ -2460,8 +2470,8 @@ static void cargo_iter_next(struct iterator *it)
     }
 
     /* Variant 3: return to previous level, and do same tests. */
-    piter = iter->links[iter->depth-- - 2];
-  } while (0 < iter->depth);
+    iter->depth--;
+  }
 }
 
 /****************************************************************************
