@@ -15,11 +15,13 @@ FCVER=$(../fc_version)
 
 if ! flatpak-builder --user --repo=repo --force-clean build org.freeciv.gtk322.yml ||
    ! flatpak-builder --user --repo=repo --force-clean build org.freeciv.mp.gtk3.yml ||
+   ! flatpak-builder --user --repo=repo --force-clean build org.freeciv.mp.gtk4.yml ||
    ! flatpak-builder --user --repo=repo --force-clean build org.freeciv.qt.yml ||
    ! flatpak-builder --user --repo=repo --force-clean build org.freeciv.sdl2.yml ||
    ! flatpak build-update-repo repo ||
    ! flatpak build-bundle repo "freeciv-gtk3.22-${FCVER}.flatpak" org.freeciv.gtk322 ||
    ! flatpak build-bundle repo "freeciv-mp-gtk3-${FCVER}.flatpak" org.freeciv.mp.gtk3 ||
+   ! flatpak build-bundle repo "freeciv-mp-gtk4-${FCVER}.flatpak" org.freeciv.mp.gtk4 ||
    ! flatpak build-bundle repo "freeciv-qt-${FCVER}.flatpak" org.freeciv.qt ||
    ! flatpak build-bundle repo "freeciv-sdl2-${FCVER}.flatpak" org.freeciv.sdl2
 then
