@@ -144,6 +144,8 @@ static void check_edited_tile_terrains(void)
     assign_continent_numbers();
     send_all_known_tiles(NULL);
     need_continents_reassigned = FALSE;
+
+    /* FIXME: adv / ai phase handling like in check_terrain_change() */
   }
 
 #ifdef SANITY_CHECKING
@@ -238,6 +240,8 @@ static bool edit_tile_terrain_handling(struct tile *ptile,
     update_tile_knowledge(ptile);
   }
 
+  tile_change_side_effects(ptile, TRUE);
+
   return TRUE;
 }
 
@@ -279,6 +283,8 @@ static bool edit_tile_extra_handling(struct tile *ptile,
     update_tile_knowledge(ptile);
   }
 
+  tile_change_side_effects(ptile, TRUE);
+
   return TRUE;
 }
 
@@ -415,6 +421,8 @@ void handle_edit_tile(struct connection *pc,
     update_tile_knowledge(ptile);
     send_tile_info(NULL, ptile, FALSE);
   }
+
+  tile_change_side_effects(ptile, TRUE);
 }
 
 /****************************************************************************
@@ -961,7 +969,7 @@ void handle_edit_player_create(struct connection *pc, int tag)
   pplayer->server.got_first_city = FALSE;
 
   pplayer->economic.gold = 0;
-  pplayer->economic = player_limit_to_max_rates(pplayer);
+  player_limit_to_max_rates(pplayer);
 
   presearch = research_get(pplayer);
   init_tech(presearch, TRUE);
