@@ -126,7 +126,7 @@ def make_documentation(file):
  *    }
  *
  *    for (i = 0; strings[i]; i++) {
- *      e = test_by_name(strings[i], mystrcasecmp);
+ *      e = test_by_name(strings[i], fc_strcasecmp);
  *      if (test_is_valid(e)) {
  *        log_verbose("Value is %d for %s", e, strings[i]);
  *      } else {
@@ -619,32 +619,30 @@ def main():
     src_root=src_dir+"/.."
     target_name=src_root+'/'+target
 
-    output=open(target_name,"w")
+    with open(target_name, "w") as output:
 
-    make_header(output)
-    make_documentation(output)
-    make_macros(output)
-    make_enum(output)
-    make_is_bitwise(output)
-    make_min(output)
-    make_max(output)
-    make_is_valid(output)
-    make_invalid(output)
-    make_begin(output)
-    make_end(output)
-    make_next(output)
-    make_name(output)
-    make_by_name(output)
-    make_translated_name(output)
-    make_bitvector(output)
-    make_undef(output)
+        make_header(output)
+        make_documentation(output)
+        make_macros(output)
+        make_enum(output)
+        make_is_bitwise(output)
+        make_min(output)
+        make_max(output)
+        make_is_valid(output)
+        make_invalid(output)
+        make_begin(output)
+        make_end(output)
+        make_next(output)
+        make_name(output)
+        make_by_name(output)
+        make_translated_name(output)
+        make_bitvector(output)
+        make_undef(output)
 
-    output.write('''
+        output.write('''
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
 ''')
 
-    output.close()
-
 main()
