@@ -134,6 +134,29 @@ enum fc_tristate fc_tristate_and(enum fc_tristate one, enum fc_tristate two)
   return TRI_YES;
 }
 
+/************************************************************************//**
+  If the directory part of the "filename" does not exist, recursively create
+  all directories until it does.
+****************************************************************************/
+bool make_dir_for_file(char *filename)
+{
+  int i;
+
+  for (i = strlen(filename) - 1 ; filename[i] != DIR_SEPARATOR_CHAR ; i--) {
+    /* Nothing */
+  }
+
+  filename[i] = '\0';
+  log_debug("Create directory \"%s\"", filename);
+
+  if (!make_dir(filename)) {
+    return FALSE;
+  }
+  filename[i] = DIR_SEPARATOR_CHAR;
+
+  return TRUE;
+}
+
 /************************************************************************//**
   An OR function for fc_tristate.
 ****************************************************************************/
@@ -539,7 +562,7 @@ bool str_to_int(const char *str, int *pint)
 }
 
 /****************************************************************************
-  Convert 'str' to it's unsigned int representation if possible.
+  Convert 'str' to its unsigned int representation if possible.
   'pint' can be NULL, then it will only test 'str' only contains
   an unsigned integer number.
 ****************************************************************************/
@@ -573,7 +596,7 @@ bool str_to_uint(const char *str, unsigned int *pint)
 }
 
 /****************************************************************************
-  Convert 'str' to it's float representation if possible. 'pfloat' can be NULL,
+  Convert 'str' to its float representation if possible. 'pfloat' can be NULL,
   then it will only test 'str' only contains a floating point number.
 ****************************************************************************/
 bool str_to_float(const char *str, float *pfloat)
@@ -1253,15 +1276,15 @@ struct fileinfo_list *fileinfolist_infix(const struct strvec *dirs,
 /***************************************************************************
   Language environmental variable (with emulation).
 ***************************************************************************/
-char *setup_langname(void)
+const char *setup_langname(void)
 {
-  char *langname = NULL;
+  const char *langname = NULL;
 
 #ifdef ENABLE_NLS
   langname = getenv("LANG");
 
 #ifdef FREECIV_MSWINDOWS
-  /* set LANG by hand if it is not set */
+  /* Set LANG by hand if it is not set */
   if (!langname) {
     switch (PRIMARYLANGID(GetUserDefaultLangID())) {
       case LANG_ARABIC:
